@@ -102,7 +102,7 @@ merge_context_free (MergeContext *merge_context)
 
 static void
 addressbook_selector_removed_cb (EBook *book,
-                                 EBookStatus status,
+                                 const GError *error,
                                  MergeContext *merge_context)
 {
 	merge_context->pending_removals--;
@@ -118,16 +118,16 @@ addressbook_selector_removed_cb (EBook *book,
 
 static void
 addressbook_selector_merge_next_cb (EBook *book,
-                                    EBookStatus status,
+                                    const GError *error,
                                     const gchar *id,
                                     MergeContext *merge_context)
 {
-	if (merge_context->remove_from_source && status == E_BOOK_ERROR_OK) {
+	if (merge_context->remove_from_source && !error) {
 		/* Remove previous contact from source. */
-		e_book_async_remove_contact (
+		e_book_async_remove_contact_ex (
 			merge_context->source_book,
 			merge_context->current_contact,
-			(EBookCallback) addressbook_selector_removed_cb,
+			(EBookExCallback) addressbook_selector_removed_cb,
 			merge_context);
 		merge_context->pending_removals++;
 	}
@@ -139,7 +139,7 @@ addressbook_selector_merge_next_cb (EBook *book,
 		eab_merging_book_add_contact (
 			merge_context->target_book,
 			merge_context->current_contact,
-			(EBookIdCallback) addressbook_selector_merge_next_cb,
+			(EBookIdExCallback) addressbook_selector_merge_next_cb,
 			merge_context);
 
 	} else if (merge_context->pending_removals == 0)
@@ -295,7 +295,7 @@ addressbook_selector_data_dropped (ESourceSelector *selector,
 	priv = E_ADDRESSBOOK_SELECTOR_GET_PRIVATE (selector);
 	g_return_val_if_fail (priv->current_view != NULL, FALSE);
 
-	string = (const gchar *) selection_data->data;
+	string = (const gchar *) gtk_selection_data_get_data (selection_data);
 	remove_from_source = (action == GDK_ACTION_MOVE);
 
 	target_book = e_book_new (destination, NULL);
@@ -319,7 +319,7 @@ addressbook_selector_data_dropped (ESourceSelector *selector,
 
 	eab_merging_book_add_contact (
 		target_book, merge_context->current_contact,
-		(EBookIdCallback) addressbook_selector_merge_next_cb,
+		(EBookIdExCallback) addressbook_selector_merge_next_cb,
 		merge_context);
 
 	return TRUE;
