@@ -66,13 +66,17 @@
 
 #define d(x)
 
-static void status_message     (EAddressbookView *view, const gchar *status);
-static void search_result      (EAddressbookView *view, EBookViewStatus status);
-static void folder_bar_message (EAddressbookView *view, const gchar *status);
-static void stop_state_changed (GtkObject *object, EAddressbookView *view);
-static void backend_died       (EAddressbookView *view);
-
-static void command_state_change (EAddressbookView *view);
+static void	status_message			(EAddressbookView *view,
+						 const gchar *status);
+static void	search_result			(EAddressbookView *view,
+						 EBookViewStatus status,
+						 const gchar *error_msg);
+static void	folder_bar_message		(EAddressbookView *view,
+						 const gchar *status);
+static void	stop_state_changed		(GtkObject *object,
+						 EAddressbookView *view);
+static void	backend_died			(EAddressbookView *view);
+static void	command_state_change		(EAddressbookView *view);
 
 struct _EAddressbookViewPrivate {
 	gpointer shell_view;  /* weak pointer */
@@ -241,6 +245,7 @@ table_drag_data_get (ETable *table,
 	EAddressbookModel *model;
 	EBook *book;
 	GList *contact_list;
+	GdkAtom target;
 	gchar *value;
 
 	if (!E_IS_ADDRESSBOOK_TABLE_ADAPTER (view->priv->object))
@@ -250,14 +255,15 @@ table_drag_data_get (ETable *table,
 	book = e_addressbook_model_get_book (model);
 
 	contact_list = e_addressbook_view_get_selected (view);
+	target = gtk_selection_data_get_target (selection_data);
 
 	switch (info) {
 		case DND_TARGET_TYPE_VCARD:
 			value = eab_contact_list_to_string (contact_list);
 
 			gtk_selection_data_set (
-				selection_data, selection_data->target,
-				8, (guchar *)value, strlen (value));
+				selection_data, target, 8,
+				(guchar *)value, strlen (value));
 
 			g_free (value);
 			break;
@@ -267,8 +273,8 @@ table_drag_data_get (ETable *table,
 				book, contact_list);
 
 			gtk_selection_data_set (
-				selection_data, selection_data->target,
-				8, (guchar *)value, strlen (value));
+				selection_data, target, 8,
+				(guchar *)value, strlen (value));
 
 			g_free (value);
 			break;
@@ -755,7 +761,7 @@ addressbook_view_class_init (EAddressbookViewClass *class)
 		PROP_MODEL,
 		g_param_spec_object (
 			"model",
-			_("Model"),
+			"Model",
 			NULL,
 			E_TYPE_ADDRESSBOOK_MODEL,
 			G_PARAM_READABLE));
@@ -771,7 +777,7 @@ addressbook_view_class_init (EAddressbookViewClass *class)
 		PROP_SHELL_VIEW,
 		g_param_spec_object (
 			"shell-view",
-			_("Shell View"),
+			"Shell View",
 			NULL,
 			E_TYPE_SHELL_VIEW,
 			G_PARAM_READWRITE |
@@ -782,7 +788,7 @@ addressbook_view_class_init (EAddressbookViewClass *class)
 		PROP_SOURCE,
 		g_param_spec_object (
 			"source",
-			_("Source"),
+			"Source",
 			NULL,
 			E_TYPE_SOURCE,
 			G_PARAM_READWRITE |
@@ -1082,14 +1088,15 @@ status_message (EAddressbookView *view,
 
 static void
 search_result (EAddressbookView *view,
-               EBookViewStatus status)
+               EBookViewStatus status,
+	       const gchar *error_msg)
 {
 	EShellView *shell_view;
 	EShellWindow *shell_window;
 
 	shell_view = e_addressbook_view_get_shell_view (view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
-	eab_search_result_dialog (GTK_WIDGET (shell_window), status);
+	eab_search_result_dialog (GTK_WIDGET (shell_window), status, error_msg);
 }
 
 static void
@@ -1150,11 +1157,12 @@ contact_print_button_draw_page (GtkPrintOperation *operation,
                                 EPrintable *printable)
 {
 	GtkPageSetup *setup;
-	gdouble top_margin;
+	gdouble top_margin, page_width;
 	cairo_t *cr;
 
 	setup = gtk_print_context_get_page_setup (context);
 	top_margin = gtk_page_setup_get_top_margin (setup, GTK_UNIT_POINTS);
+	page_width = gtk_page_setup_get_page_width (setup, GTK_UNIT_POINTS);
 
 	cr = gtk_print_context_get_cairo_context (context);
 
@@ -1162,8 +1170,9 @@ contact_print_button_draw_page (GtkPrintOperation *operation,
 
 	while (e_printable_data_left (printable)) {
 		cairo_save (cr);
+		contact_page_draw_footer(operation,context,page_nr++);
 		e_printable_print_page (
-			printable, context, 6.5 * 72, top_margin + 10, TRUE);
+			printable, context, page_width - 16, top_margin + 10, TRUE);
 		cairo_restore (cr);
 	}
 }
@@ -1248,9 +1257,9 @@ e_addressbook_view_print (EAddressbookView *view,
  * which a user doesnt have write permission
  */
 static void
-delete_contacts_cb (EBook *book,  EBookStatus status,  gpointer closure)
+delete_contacts_cb (EBook *book, const GError *error, gpointer closure)
 {
-	switch (status) {
+	switch (error ? error->code : E_BOOK_ERROR_OK) {
 		case E_BOOK_ERROR_OK :
 		case E_BOOK_ERROR_CANCELLED :
 			break;
@@ -1261,7 +1270,7 @@ delete_contacts_cb (EBook *book,  EBookStatus status,  gpointer closure)
 			break;
 		default :
 			/* Unknown error */
-			eab_error_dialog (_("Failed to delete contact"), status);
+			eab_error_dialog (_("Failed to delete contact"), error);
 			break;
 	}
 }
@@ -1387,10 +1396,10 @@ e_addressbook_view_delete_selection(EAddressbookView *view, gboolean is_delete)
 		}
 
 		/* Remove the cards all at once. */
-		e_book_async_remove_contacts (book,
-					      ids,
-					      delete_contacts_cb,
-					      NULL);
+		e_book_async_remove_contacts_ex (book,
+						 ids,
+						 delete_contacts_cb,
+						 NULL);
 
 		g_list_free (ids);
 	}
@@ -1398,10 +1407,10 @@ e_addressbook_view_delete_selection(EAddressbookView *view, gboolean is_delete)
 		for (l=list;l;l=g_list_next(l)) {
 			contact = l->data;
 			/* Remove the card. */
-			e_book_async_remove_contact (book,
-						     contact,
-						     delete_contacts_cb,
-						     NULL);
+			e_book_async_remove_contact_ex (book,
+							contact,
+							delete_contacts_cb,
+							NULL);
 		}
 	}
 
@@ -1503,18 +1512,27 @@ view_transfer_contacts (EAddressbookView *view,
 	GtkWindow *parent;
 
 	book = e_addressbook_model_get_book (view->priv->model);
+	parent = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (view)));
 
 	if (all) {
 		EBookQuery *query;
+		GError *error = NULL;
 
 		query = e_book_query_any_field_contains ("");
-		e_book_get_contacts (book, query, &contacts, NULL);
+		e_book_get_contacts (book, query, &contacts, &error);
 		e_book_query_unref (query);
+
+		if (error) {
+			e_alert_run_dialog_for_args (
+				parent, "addressbook:search-error",
+				error->message, NULL);
+			g_error_free (error);
+			return;
+		}
 	} else {
 		contacts = e_addressbook_view_get_selected (view);
 	}
 
-	parent = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (view)));
 	eab_transfer_contacts (book, contacts, delete_from_source, parent);
 
 	g_object_unref(book);
