@@ -83,19 +83,22 @@ e_minicard_view_drag_data_get(GtkWidget *widget,
 			      guint time,
 			      EMinicardView *view)
 {
+	GdkAtom target;
+
 	if (!E_IS_MINICARD_VIEW(view))
 		return;
 
+	target = gtk_selection_data_get_target (selection_data);
+
 	switch (info) {
 	case DND_TARGET_TYPE_VCARD_LIST: {
 		gchar *value;
 
 		value = eab_contact_list_to_string (view->drag_list);
 
-		gtk_selection_data_set (selection_data,
-					selection_data->target,
-					8,
-					(guchar *)value, strlen (value));
+		gtk_selection_data_set (
+			selection_data, target, 8,
+			(guchar *) value, strlen (value));
 		g_free (value);
 		break;
 	}
@@ -106,10 +109,9 @@ e_minicard_view_drag_data_get(GtkWidget *widget,
 		g_object_get (view->adapter, "book", &book, NULL);
 		value = eab_book_and_contact_list_to_string (book, view->drag_list);
 
-		gtk_selection_data_set (selection_data,
-					selection_data->target,
-					8,
-					(guchar *)value, strlen (value));
+		gtk_selection_data_set (
+			selection_data, target, 8,
+			(guchar *) value, strlen (value));
 		g_free (value);
 		break;
 	}
@@ -454,7 +456,7 @@ e_minicard_view_selection_event (EReflow *reflow,
 
 typedef struct {
 	EMinicardView *view;
-	EBookCallback cb;
+	EBookExCallback cb;
 	gpointer closure;
 } ViewCbClosure;
 
@@ -465,7 +467,7 @@ do_remove (gint i, gpointer user_data)
 	EContact *contact;
 	ViewCbClosure *viewcbclosure = user_data;
 	EMinicardView *view = viewcbclosure->view;
-	EBookCallback cb = viewcbclosure->cb;
+	EBookExCallback cb = viewcbclosure->cb;
 	gpointer closure = viewcbclosure->closure;
 
 	g_object_get (view->adapter,
@@ -474,7 +476,7 @@ do_remove (gint i, gpointer user_data)
 
 	contact = e_addressbook_reflow_adapter_get_contact (view->adapter, i);
 
-	e_book_async_remove_contact(book, contact, cb, closure);
+	e_book_async_remove_contact_ex (book, contact, cb, closure);
 
 	g_object_unref (contact);
 }
@@ -524,29 +526,29 @@ e_minicard_view_class_init (EMinicardViewClass *klass)
 
 	g_object_class_install_property (object_class, PROP_ADAPTER,
 					 g_param_spec_object ("adapter",
-							      _("Adapter"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Adapter",
+							      NULL,
 							      E_TYPE_ADDRESSBOOK_REFLOW_ADAPTER,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_BOOK,
 					 g_param_spec_object ("book",
-							      _("Book"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Book",
+							      NULL,
 							      E_TYPE_BOOK,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_QUERY,
 					 g_param_spec_string ("query",
-							      _("Query"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Query",
+							      NULL,
 							      NULL,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_EDITABLE,
 					 g_param_spec_boolean ("editable",
-							       _("Editable"),
-							       /*_( */"XXX blurb" /*)*/,
+							       "Editable",
+							       NULL,
 							       FALSE,
 							       G_PARAM_READWRITE));
 
@@ -622,7 +624,7 @@ e_minicard_view_get_type (void)
 
 void
 e_minicard_view_remove_selection(EMinicardView *view,
-				 EBookCallback  cb,
+				 EBookExCallback  cb,
 				 gpointer       closure)
 {
 	ViewCbClosure viewcbclosure;
