@@ -35,7 +35,10 @@
 static GHashTable *source_lists_hash = NULL;
 
 static gchar *
-auth_func_cb (ECal *ecal, const gchar *prompt, const gchar *key, gpointer user_data)
+auth_func_cb (ECal *ecal,
+              const gchar *prompt,
+              const gchar *key,
+              gpointer user_data)
 {
 	gboolean remember;
 	gchar *password, *auth_domain;
@@ -48,11 +51,16 @@ auth_func_cb (ECal *ecal, const gchar *prompt, const gchar *key, gpointer user_d
 	password = e_passwords_get_password (component_name, key);
 
 	if (!password)
-		password = e_passwords_ask_password (_("Enter password"), component_name, key, prompt,
-						     E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET|E_PASSWORDS_ONLINE,
-						     &remember,
-						     NULL);
+		password = e_passwords_ask_password (
+			_("Enter password"),
+			component_name, key, prompt,
+			E_PASSWORDS_REMEMBER_FOREVER |
+			E_PASSWORDS_SECRET |
+			E_PASSWORDS_ONLINE,
+			&remember, NULL);
+
 	g_free (auth_domain);
+
 	return password;
 }
 
@@ -73,7 +81,7 @@ build_pass_key (ECal *ecal)
 }
 
 void
-auth_cal_forget_password (ECal *ecal)
+e_auth_cal_forget_password (ECal *ecal)
 {
 	ESource *source = NULL;
 	const gchar *auth_domain = NULL, *component_name = NULL,  *auth_type = NULL;
@@ -95,7 +103,7 @@ auth_cal_forget_password (ECal *ecal)
 }
 
 ECal *
-auth_new_cal_from_default (ECalSourceType type)
+e_auth_new_cal_from_default (ECalSourceType type)
 {
 	ECal *ecal = NULL;
 
@@ -106,7 +114,7 @@ auth_new_cal_from_default (ECalSourceType type)
 }
 
 ECal *
-auth_new_cal_from_source (ESource *source, ECalSourceType type)
+e_auth_new_cal_from_source (ESource *source, ECalSourceType type)
 {
 	ECal *cal;
 
@@ -118,7 +126,7 @@ auth_new_cal_from_source (ESource *source, ECalSourceType type)
 }
 
 ECal *
-auth_new_cal_from_uri (const gchar *uri, ECalSourceType type)
+e_auth_new_cal_from_uri (const gchar *uri, ECalSourceType type)
 {
 	ESourceGroup *group = NULL;
 	ESource *source = NULL;
@@ -139,7 +147,8 @@ auth_new_cal_from_uri (const gchar *uri, ECalSourceType type)
 	if (source_list) {
 		GSList *gl;
 
-		for (gl = e_source_list_peek_groups (source_list); gl != NULL && source == NULL; gl = gl->next) {
+		for (gl = e_source_list_peek_groups (source_list);
+		     gl != NULL && source == NULL; gl = gl->next) {
 			GSList *sl;
 
 			for (sl = e_source_group_peek_sources (gl->data); sl != NULL; sl = sl->next) {
@@ -172,7 +181,7 @@ auth_new_cal_from_uri (const gchar *uri, ECalSourceType type)
 		}
 	}
 
-	cal = auth_new_cal_from_source (source, type);
+	cal = e_auth_new_cal_from_source (source, type);
 
 	g_object_unref (source);
 	if (group)
