@@ -29,7 +29,7 @@ composer_setup_charset_menu (EMsgComposer *composer)
 	guint merge_id;
 
 	ui_manager = gtkhtml_editor_get_ui_manager (GTKHTML_EDITOR (composer));
-	path = "/main-menu/edit-menu/pre-spell-check/charset-menu";
+	path = "/main-menu/options-menu/charset-menu";
 	merge_id = gtk_ui_manager_new_merge_id (ui_manager);
 
 	list = gtk_action_group_list_actions (composer->priv->charset_actions);
@@ -109,14 +109,14 @@ msg_composer_url_requested_cb (GtkHTML *html,
 
 	array = g_byte_array_new ();
 	camel_stream = camel_stream_mem_new_with_byte_array (array);
-	wrapper = camel_medium_get_content_object (CAMEL_MEDIUM (mime_part));
-	camel_data_wrapper_decode_to_stream (wrapper, camel_stream);
+	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
+	camel_data_wrapper_decode_to_stream (wrapper, camel_stream, NULL);
 
 	gtk_html_write (html, stream, (gchar *) array->data, array->len);
 
 	gtk_html_end (html, stream, GTK_HTML_STREAM_OK);
 
-	camel_object_unref (camel_stream);
+	g_object_unref (camel_stream);
 
 	/* gtk_html_end() destroys the GtkHTMLStream, so we need to
 	 * stop the signal emission so nothing else tries to use it. */
@@ -127,6 +127,7 @@ void
 e_composer_private_constructed (EMsgComposer *composer)
 {
 	EMsgComposerPrivate *priv = composer->priv;
+	EShell *shell;
 	EFocusTracker *focus_tracker;
 	GtkhtmlEditor *editor;
 	GtkUIManager *ui_manager;
@@ -145,9 +146,20 @@ e_composer_private_constructed (EMsgComposer *composer)
 	html = gtkhtml_editor_get_html (editor);
 	ui_manager = gtkhtml_editor_get_ui_manager (editor);
 
-	if (composer->lite) {
+	shell = e_shell_get_default ();
+
+	if (e_msg_composer_get_lite ()) {
+#if 0
+		/* In the lite composer, for small screens, we are not ready yet
+		 * to hide the menubar.  It still has useful items like the ones
+		 * to show/hide the various header fields, plus the security options.
+		 *
+		 * When we move those options out of the menu and into the composer's
+		 * toplevel, we can probably get rid of the menu.
+		 */
 		widget = gtkhtml_editor_get_managed_widget (editor, "/main-menu");
 		gtk_widget_hide (widget);
+#endif
 		widget = gtkhtml_editor_get_managed_widget (editor, "/main-toolbar");
 		gtk_toolbar_set_style (GTK_TOOLBAR (widget), GTK_TOOLBAR_BOTH_HORIZ);
 		gtk_widget_hide (widget);
@@ -176,7 +188,7 @@ e_composer_private_constructed (EMsgComposer *composer)
 	priv->inline_images_by_url = g_hash_table_new_full (
 		g_str_hash, g_str_equal,
 		(GDestroyNotify) g_free,
-		(GDestroyNotify) camel_object_unref);
+		(GDestroyNotify) g_object_unref);
 
 	priv->charset = e_composer_get_default_charset ();
 
@@ -193,6 +205,23 @@ e_composer_private_constructed (EMsgComposer *composer)
 	send_widget = gtk_ui_manager_get_widget (ui_manager, path);
 	gtk_tool_item_set_is_important (GTK_TOOL_ITEM (send_widget), TRUE);
 
+	/* Tooltips for all buttons in toolbar that don't yet have one */
+	path = "/main-toolbar/undo";
+	widget = gtk_ui_manager_get_widget (ui_manager, path);
+	gtk_widget_set_tooltip_text (widget, _("Undo the last action"));
+
+	path = "/main-toolbar/redo";
+	widget = gtk_ui_manager_get_widget (ui_manager, path);
+	gtk_widget_set_tooltip_text (widget, _("Redo the last undone action"));
+
+	path = "/main-toolbar/show-find";
+	widget = gtk_ui_manager_get_widget (ui_manager, path);
+	gtk_widget_set_tooltip_text (widget, _("Search for text"));
+
+	path = "/main-toolbar/show-replace";
+	widget = gtk_ui_manager_get_widget (ui_manager, path);
+	gtk_widget_set_tooltip_text (widget, _("Search for and replace text"));
+
 	composer_setup_charset_menu (composer);
 
 	if (error != NULL) {
@@ -223,11 +252,11 @@ e_composer_private_constructed (EMsgComposer *composer)
 
 	container = editor->vbox;
 
-	widget = e_composer_header_table_new ();
+	widget = e_composer_header_table_new (shell);
 	gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
 	gtk_box_pack_start (GTK_BOX (editor->vbox), widget, FALSE, FALSE, 0);
-	if (composer->lite)
-		gtk_box_reorder_child (GTK_BOX (editor->vbox), widget, 0);
+	if (e_msg_composer_get_lite ())
+		gtk_box_reorder_child (GTK_BOX (editor->vbox), widget, 1);
 	else
 		gtk_box_reorder_child (GTK_BOX (editor->vbox), widget, 2);
 
@@ -236,7 +265,7 @@ e_composer_private_constructed (EMsgComposer *composer)
 
 	/* Construct the attachment paned. */
 
-	if (composer->lite) {
+	if (e_msg_composer_get_lite ()) {
 		e_attachment_paned_set_default_height (75); /* short attachment bar for Anjal */
 		e_attachment_icon_view_set_default_icon_size (GTK_ICON_SIZE_BUTTON);
 	}
@@ -245,7 +274,7 @@ e_composer_private_constructed (EMsgComposer *composer)
 	priv->attachment_paned = g_object_ref (widget);
 	gtk_widget_show (widget);
 
-	if (composer->lite) {
+	if (e_msg_composer_get_lite ()) {
 		GtkWidget *tmp, *tmp1, *tmp_box, *container;
 		GtkWidget *combo;
 
@@ -263,13 +292,17 @@ e_composer_private_constructed (EMsgComposer *composer)
 		gtk_box_pack_start ((GtkBox *)tmp, tmp1, FALSE, FALSE, 0);
 		tmp1 = gtk_label_new_with_mnemonic (_("S_end"));
 		gtk_box_pack_start ((GtkBox *)tmp, tmp1, FALSE, FALSE, 6);
-		gtk_widget_show_all(tmp);
+		gtk_widget_show_all (tmp);
 		gtk_widget_reparent (send_widget, tmp_box);
-		gtk_box_set_child_packing ((GtkBox *)tmp_box, send_widget, FALSE, FALSE, 6, GTK_PACK_END);
+		gtk_box_set_child_packing (
+			GTK_BOX (tmp_box), send_widget,
+			FALSE, FALSE, 6, GTK_PACK_END);
 		gtk_tool_item_set_is_important (GTK_TOOL_ITEM (send_widget), TRUE);
 		send_widget = gtk_bin_get_child ((GtkBin *)send_widget);
-		gtk_container_remove((GtkContainer *)send_widget, gtk_bin_get_child ((GtkBin *)send_widget));
-		gtk_container_add((GtkContainer *)send_widget, tmp);
+		gtk_container_remove (
+			GTK_CONTAINER (send_widget),
+			gtk_bin_get_child (GTK_BIN (send_widget)));
+		gtk_container_add ((GtkContainer *)send_widget, tmp);
 		gtk_button_set_relief ((GtkButton *)send_widget, GTK_RELIEF_NORMAL);
 		path = "/main-toolbar/pre-main-toolbar/save-draft";
 		send_widget = gtk_ui_manager_get_widget (ui_manager, path);
@@ -279,16 +312,20 @@ e_composer_private_constructed (EMsgComposer *composer)
 		gtk_box_pack_start ((GtkBox *)tmp, tmp1, FALSE, FALSE, 0);
 		tmp1 = gtk_label_new_with_mnemonic (_("Save draft"));
 		gtk_box_pack_start ((GtkBox *)tmp, tmp1, FALSE, FALSE, 3);
-		gtk_widget_show_all(tmp);
+		gtk_widget_show_all (tmp);
 		gtk_widget_reparent (send_widget, tmp_box);
-		gtk_box_set_child_packing ((GtkBox *)tmp_box, send_widget, FALSE, FALSE, 6, GTK_PACK_END);
+		gtk_box_set_child_packing (
+			GTK_BOX (tmp_box), send_widget,
+			FALSE, FALSE, 6, GTK_PACK_END);
 		gtk_tool_item_set_is_important (GTK_TOOL_ITEM (send_widget), TRUE);
 		send_widget = gtk_bin_get_child ((GtkBin *)send_widget);
-		gtk_container_remove((GtkContainer *)send_widget, gtk_bin_get_child ((GtkBin *)send_widget));
-		gtk_container_add((GtkContainer *)send_widget, tmp);
+		gtk_container_remove (
+			GTK_CONTAINER (send_widget),
+			gtk_bin_get_child (GTK_BIN (send_widget)));
+		gtk_container_add ((GtkContainer *)send_widget, tmp);
 		gtk_button_set_relief ((GtkButton *)send_widget, GTK_RELIEF_NORMAL);
 
-		gtk_widget_show(tmp_box);
+		gtk_widget_show (tmp_box);
 		gtk_box_pack_end (GTK_BOX (container), tmp_box, FALSE, FALSE, 3);
 	}
 
@@ -326,10 +363,6 @@ e_composer_private_constructed (EMsgComposer *composer)
 				action = ACTION (VIEW_CC);
 				break;
 
-			case E_COMPOSER_HEADER_FROM:
-				action = ACTION (VIEW_FROM);
-				break;
-
 			case E_COMPOSER_HEADER_REPLY_TO:
 				action = ACTION (VIEW_REPLY_TO);
 				break;
@@ -415,7 +448,7 @@ e_composer_private_dispose (EMsgComposer *composer)
 	g_hash_table_remove_all (composer->priv->inline_images_by_url);
 
 	if (composer->priv->redirect != NULL) {
-		camel_object_unref (composer->priv->redirect);
+		g_object_unref (composer->priv->redirect);
 		composer->priv->redirect = NULL;
 	}
 }
@@ -508,6 +541,27 @@ e_composer_get_default_charset (void)
 	return charset;
 }
 
+gboolean
+e_composer_paste_html (EMsgComposer *composer,
+                       GtkClipboard *clipboard)
+{
+	GtkhtmlEditor *editor;
+	gchar *html;
+
+	g_return_val_if_fail (E_IS_MSG_COMPOSER (composer), FALSE);
+	g_return_val_if_fail (GTK_IS_CLIPBOARD (clipboard), FALSE);
+
+	html = e_clipboard_wait_for_html (clipboard);
+	g_return_val_if_fail (html != NULL, FALSE);
+
+	editor = GTKHTML_EDITOR (composer);
+	gtkhtml_editor_insert_html (editor, html);
+
+	g_free (html);
+
+	return TRUE;
+}
+
 gboolean
 e_composer_paste_image (EMsgComposer *composer,
                         GtkClipboard *clipboard)
@@ -582,6 +636,27 @@ exit:
 	return success;
 }
 
+gboolean
+e_composer_paste_text (EMsgComposer *composer,
+                       GtkClipboard *clipboard)
+{
+	GtkhtmlEditor *editor;
+	gchar *text;
+
+	g_return_val_if_fail (E_IS_MSG_COMPOSER (composer), FALSE);
+	g_return_val_if_fail (GTK_IS_CLIPBOARD (clipboard), FALSE);
+
+	text = gtk_clipboard_wait_for_text (clipboard);
+	g_return_val_if_fail (text != NULL, FALSE);
+
+	editor = GTKHTML_EDITOR (composer);
+	gtkhtml_editor_insert_text (editor, text);
+
+	g_free (text);
+
+	return TRUE;
+}
+
 gboolean
 e_composer_paste_uris (EMsgComposer *composer,
                        GtkClipboard *clipboard)
