@@ -20,6 +20,11 @@
  *
  */
 
+/**
+ * SECTION: e-util
+ * @include: e-util/e-util.h
+ **/
+
 #include <config.h>
 
 #include <stdlib.h>
@@ -39,12 +44,11 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
-#include <camel/camel-url.h>
-
 #ifdef G_OS_WIN32
 #include <windows.h>
 #endif
 
+#include <camel/camel.h>
 #include <libedataserver/e-data-server-util.h>
 #include <libedataserver/e-categories.h>
 #include <libedataserver/e-source-list.h>
@@ -55,21 +59,27 @@
 #include "e-util-private.h"
 
 /**
- * e_get_user_data_dir:
+ * e_get_gnome2_user_dir:
  *
- * Returns the base directory for Evolution-specific user data.
- * The string is owned by Evolution and must not be modified or freed.
+ * Returns the base directory for user data, according to libgnome.
+ * The directory can be overridden by setting the GNOME22_USER_DIR
+ * environment variable.  The string is owned by Evolution and must
+ * not be modified or freed.
  *
- * Returns: base directory for user data
+ * Returns: base directory for GNOME user data
  **/
 const gchar *
-e_get_user_data_dir (void)
+e_get_gnome2_user_dir (void)
 {
 	static gchar *dirname = NULL;
 
+#ifndef G_OS_WIN32
 	if (G_UNLIKELY (dirname == NULL))
+		dirname = g_strdup (g_getenv ("GNOME22_USER_DIR"));
+#endif
+    if (dirname == NULL)
 		dirname = g_build_filename (
-			g_get_home_dir (), ".evolution", NULL);
+			g_get_home_dir (), ".gnome2", NULL);
 
 	return dirname;
 }
@@ -94,7 +104,7 @@ e_get_accels_filename (void)
 
 	if (G_UNLIKELY (filename == NULL))
 		filename = g_build_filename (
-			g_get_home_dir (), ".gnome2",
+			e_get_gnome2_user_dir (),
 			"accels", PACKAGE, NULL);
 
 	return filename;
@@ -117,7 +127,6 @@ e_show_uri (GtkWindow *parent,
 	GtkWidget *dialog;
 	GdkScreen *screen = NULL;
 	GError *error = NULL;
-	gchar *decoded_uri;
 	guint32 timestamp;
 
 	g_return_if_fail (uri != NULL);
@@ -127,11 +136,8 @@ e_show_uri (GtkWindow *parent,
 	if (parent != NULL)
 		screen = gtk_widget_get_screen (GTK_WIDGET (parent));
 
-	decoded_uri = g_strdup (uri);
-	camel_url_decode (decoded_uri);
-
-	if (gtk_show_uri (screen, decoded_uri, timestamp, &error))
-		goto exit;
+	if (gtk_show_uri (screen, uri, timestamp, &error))
+		return;
 
 	dialog = gtk_message_dialog_new_with_markup (
 		parent, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -146,9 +152,6 @@ e_show_uri (GtkWindow *parent,
 
 	gtk_widget_destroy (dialog);
 	g_error_free (error);
-
-exit:
-	g_free (decoded_uri);
 }
 
 /**
@@ -237,7 +240,7 @@ e_lookup_action (GtkUIManager *ui_manager,
 		iter = g_list_next (iter);
 	}
 
-	g_critical ("%s: action `%s' not found", G_STRFUNC, action_name);
+	g_critical ("%s: action '%s' not found", G_STRFUNC, action_name);
 
 	return NULL;
 }
@@ -276,7 +279,7 @@ e_lookup_action_group (GtkUIManager *ui_manager,
 		iter = g_list_next (iter);
 	}
 
-	g_critical ("%s: action group `%s' not found", G_STRFUNC, group_name);
+	g_critical ("%s: action group '%s' not found", G_STRFUNC, group_name);
 
 	return NULL;
 }
@@ -537,15 +540,15 @@ e_str_without_underscores (const gchar *string)
 	new_string = g_malloc (strlen (string) + 1);
 
 	dp = new_string;
-	for (sp = string; *sp != '\0'; sp ++) {
+	for (sp = string; *sp != '\0'; sp++) {
 		if (*sp != '_') {
 			*dp = *sp;
-			dp ++;
+			dp++;
 		} else if (sp[1] == '_') {
 			/* Translate "__" in "_".  */
 			*dp = '_';
-			dp ++;
-			sp ++;
+			dp++;
+			sp++;
 		}
 	}
 	*dp = 0;
@@ -684,7 +687,7 @@ e_format_number (gint number)
 		}
 		char_length += strlen(group);
 		list = g_list_prepend(list, group);
-		group_count ++;
+		group_count++;
 	}
 
 	if (list) {
@@ -1455,32 +1458,3 @@ e_util_set_source_combo_box_list (GtkWidget *source_combo_box,
 	g_object_unref (gconf_client);
 }
 
-static gpointer
-e_camel_object_copy (gpointer camel_object)
-{
-	if (CAMEL_IS_OBJECT (camel_object))
-		camel_object_ref (camel_object);
-
-	return camel_object;
-}
-
-static void
-e_camel_object_free (gpointer camel_object)
-{
-	if (CAMEL_IS_OBJECT (camel_object))
-		camel_object_unref (camel_object);
-}
-
-GType
-e_camel_object_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-		type = g_boxed_type_register_static (
-			"ECamelObject",
-			(GBoxedCopyFunc) e_camel_object_copy,
-			(GBoxedFreeFunc) e_camel_object_free);
-
-	return type;
-}
