@@ -31,23 +31,6 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
-#include <camel/camel-stream.h>
-#include <camel/camel-stream-mem.h>
-#include <camel/camel-multipart.h>
-#include <camel/camel-multipart-encrypted.h>
-#include <camel/camel-multipart-signed.h>
-#include <camel/camel-medium.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-gpg-context.h>
-#include <camel/camel-smime-context.h>
-#include <camel/camel-string-utils.h>
-#include <camel/camel-stream-filter.h>
-#include <camel/camel-stream-null.h>
-#include <camel/camel-stream-mem.h>
-#include <camel/camel-mime-filter-charset.h>
-#include <camel/camel-mime-filter-windows.h>
-#include <camel/camel-mime-filter-pgp.h>
-
 #include "em-format.h"
 #include "e-util/e-util.h"
 #include "shell/e-shell.h"
@@ -93,7 +76,7 @@ emf_free_cache(struct _EMFormatCache *efc)
 	if (efc->valid)
 		camel_cipher_validity_free(efc->valid);
 	if (efc->secured)
-		camel_object_unref(efc->secured);
+		g_object_unref (efc->secured);
 	g_free(efc);
 }
 
@@ -115,10 +98,7 @@ emf_finalize (GObject *object)
 	EMFormat *emf = EM_FORMAT (object);
 
 	if (emf->session)
-		camel_object_unref (emf->session);
-
-	if (emf->message)
-		camel_object_unref (emf->message);
+		g_object_unref (emf->session);
 
 	g_hash_table_destroy (emf->inline_table);
 
@@ -192,7 +172,7 @@ emf_init (EMFormat *emf)
 	emf->session = e_shell_settings_get_pointer (shell_settings, "mail-session");
 	g_return_if_fail (emf->session != NULL);
 
-	camel_object_ref (emf->session);
+	g_object_ref (emf->session);
 }
 
 GType
@@ -420,7 +400,7 @@ em_format_add_puri (EMFormat *emf,
 	puri->part_id = g_strdup(emf->part_id->str);
 
 	if (part) {
-		camel_object_ref(part);
+		g_object_ref (part);
 		puri->part = part;
 	}
 
@@ -588,7 +568,7 @@ emf_clear_puri_node (GNode *node)
 		g_free(pn->cid);
 		g_free(pn->part_id);
 		if (pn->part)
-			camel_object_unref(pn->part);
+			g_object_unref (pn->part);
 		g_free(pn);
 	}
 
@@ -673,11 +653,7 @@ em_format_part_as(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const
 		if (handle != NULL
 		    && !em_format_is_attachment(emf, part)) {
 			d(printf("running handler for type '%s'\n", mime_type));
-			if (is_fallback)
-				camel_object_meta_set (part, "EMF-Fallback", "1");
-			handle->handler(emf, stream, part, handle);
-			if (is_fallback)
-				camel_object_meta_set (part, "EMF-Fallback",  NULL);
+			handle->handler(emf, stream, part, handle, is_fallback);
 			goto finish;
 		}
 		d(printf("this type is an attachment? '%s'\n", mime_type));
@@ -700,7 +676,7 @@ em_format_part(EMFormat *emf, CamelStream *stream, CamelMimePart *part)
 	gchar *mime_type;
 	CamelDataWrapper *dw;
 
-	dw = camel_medium_get_content_object((CamelMedium *)part);
+	dw = camel_medium_get_content ((CamelMedium *)part);
 	mime_type = camel_data_wrapper_get_mime_type(dw);
 	if (mime_type) {
 		camel_strdown(mime_type);
@@ -720,7 +696,7 @@ emf_clone_inlines(gpointer key, gpointer val, gpointer data)
 	if (emfc->valid)
 		new->valid = camel_cipher_validity_clone(emfc->valid);
 	if (emfc->secured)
-		camel_object_ref((new->secured = emfc->secured));
+		g_object_ref ((new->secured = emfc->secured));
 }
 
 static void
@@ -755,9 +731,9 @@ emf_format_clone(EMFormat *emf, CamelFolder *folder, const gchar *uid, CamelMime
 	/* what a mess */
 	if (folder != emf->folder) {
 		if (emf->folder)
-			camel_object_unref(emf->folder);
+			g_object_unref (emf->folder);
 		if (folder)
-			camel_object_ref(folder);
+			g_object_ref (folder);
 		emf->folder = folder;
 	}
 
@@ -768,9 +744,9 @@ emf_format_clone(EMFormat *emf, CamelFolder *folder, const gchar *uid, CamelMime
 
 	if (msg != emf->message) {
 		if (emf->message)
-			camel_object_unref(emf->message);
+			g_object_unref (emf->message);
 		if (msg)
-			camel_object_ref(msg);
+			g_object_ref (msg);
 		emf->message = msg;
 	}
 
@@ -1027,7 +1003,7 @@ void em_format_add_header(EMFormat *emf, const gchar *name, guint32 flags)
 gint em_format_is_attachment(EMFormat *emf, CamelMimePart *part)
 {
 	/*CamelContentType *ct = camel_mime_part_get_content_type(part);*/
-	CamelDataWrapper *dw = camel_medium_get_content_object((CamelMedium *)part);
+	CamelDataWrapper *dw = camel_medium_get_content ((CamelMedium *)part);
 
 	if (!dw)
 		return 0;
@@ -1208,12 +1184,12 @@ em_format_busy (EMFormat *emf)
 void
 em_format_format_content(EMFormat *emf, CamelStream *stream, CamelMimePart *part)
 {
-	CamelDataWrapper *dw = camel_medium_get_content_object((CamelMedium *)part);
+	CamelDataWrapper *dw = camel_medium_get_content ((CamelMedium *)part);
 
 	if (camel_content_type_is (dw->mime_type, "text", "*"))
 		em_format_format_text(emf, stream, (CamelDataWrapper *)part);
 	else
-		camel_data_wrapper_decode_to_stream(dw, stream);
+		camel_data_wrapper_decode_to_stream(dw, stream, NULL);
 }
 
 /**
@@ -1227,12 +1203,11 @@ em_format_format_content(EMFormat *emf, CamelStream *stream, CamelMimePart *part
 void
 em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 {
-	CamelStreamFilter *filter_stream;
-	CamelMimeFilterCharset *filter;
+	CamelStream *filter_stream;
+	CamelMimeFilter *filter;
 	const gchar *charset = NULL;
 	CamelMimeFilterWindows *windows = NULL;
 	CamelStream *mem_stream = NULL;
-	GByteArray *mem_bytes;
 	gsize size;
 	gsize max;
 	GConfClient *gconf;
@@ -1250,28 +1225,32 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 		 * before we move on... */
 
 		null = camel_stream_null_new();
-		filter_stream = camel_stream_filter_new_with_stream(null);
-		camel_object_unref(null);
+		filter_stream = camel_stream_filter_new (null);
+		g_object_unref (null);
 
 		windows = (CamelMimeFilterWindows *)camel_mime_filter_windows_new(charset);
-		camel_stream_filter_add(filter_stream, (CamelMimeFilter *)windows);
+		camel_stream_filter_add (
+			CAMEL_STREAM_FILTER (filter_stream),
+			CAMEL_MIME_FILTER (windows));
 
-		camel_data_wrapper_decode_to_stream(dw, (CamelStream *)filter_stream);
-		camel_stream_flush((CamelStream *)filter_stream);
-		camel_object_unref(filter_stream);
+		camel_data_wrapper_decode_to_stream (
+			dw, (CamelStream *)filter_stream, NULL);
+		camel_stream_flush((CamelStream *)filter_stream, NULL);
+		g_object_unref (filter_stream);
 
 		charset = camel_mime_filter_windows_real_charset (windows);
 	} else if (charset == NULL) {
 		charset = emf->default_charset;
 	}
 
-	mem_bytes = g_byte_array_new ();
-	mem_stream = camel_stream_mem_new_with_byte_array (mem_bytes);
-	filter_stream = camel_stream_filter_new_with_stream(mem_stream);
+	mem_stream = (CamelStream *)camel_stream_mem_new ();
+	filter_stream = camel_stream_filter_new (mem_stream);
 
-	if ((filter = camel_mime_filter_charset_new_convert(charset, "UTF-8"))) {
-		camel_stream_filter_add(filter_stream, (CamelMimeFilter *) filter);
-		camel_object_unref(filter);
+	if ((filter = camel_mime_filter_charset_new (charset, "UTF-8"))) {
+		camel_stream_filter_add (
+			CAMEL_STREAM_FILTER (filter_stream),
+			CAMEL_MIME_FILTER (filter));
+		g_object_unref (filter);
 	}
 
 	max = -1;
@@ -1284,21 +1263,24 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 	}
 	g_object_unref (gconf);
 
-	size = camel_data_wrapper_decode_to_stream(emf->mode == EM_FORMAT_SOURCE ? (CamelDataWrapper *)dw: camel_medium_get_content_object((CamelMedium *)dw), (CamelStream *)filter_stream);
-	camel_stream_flush((CamelStream *)filter_stream);
-	camel_object_unref(filter_stream);
-	camel_stream_reset (mem_stream);
+	size = camel_data_wrapper_decode_to_stream (
+		emf->mode == EM_FORMAT_SOURCE ?
+			(CamelDataWrapper *) dw :
+			camel_medium_get_content ((CamelMedium *)dw),
+		(CamelStream *)filter_stream, NULL);
+	camel_stream_flush((CamelStream *)filter_stream, NULL);
+	g_object_unref (filter_stream);
+	camel_stream_reset (mem_stream, NULL);
 
 	if (max == -1 || size == -1 || size < (max * 1024) || emf->composer) {
-		camel_stream_write_to_stream(mem_stream, (CamelStream *)stream);
-		camel_stream_flush((CamelStream *)stream);
+		camel_stream_write_to_stream(mem_stream, (CamelStream *)stream, NULL);
+		camel_stream_flush((CamelStream *)stream, NULL);
 	} else {
-		((EMFormatClass *)G_OBJECT_GET_CLASS(emf))->format_optional(emf, stream, (CamelMimePart *)dw, mem_bytes);
+		((EMFormatClass *)G_OBJECT_GET_CLASS(emf))->format_optional(emf, stream, (CamelMimePart *)dw, mem_stream);
 	}
 
 	if (windows)
-		camel_object_unref(windows);
-	camel_object_unref (mem_stream);
+		g_object_unref (windows);
 }
 
 /**
@@ -1353,13 +1335,17 @@ add_validity_found (EMFormat *emf, CamelCipherValidity *valid)
 
 #ifdef ENABLE_SMIME
 static void
-emf_application_xpkcs7mime(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_application_xpkcs7mime (EMFormat *emf,
+                            CamelStream *stream,
+                            CamelMimePart *part,
+                            const EMFormatHandler *info,
+                            gboolean is_fallback)
 {
 	CamelCipherContext *context;
-	CamelException *ex;
 	CamelMimePart *opart;
 	CamelCipherValidity *valid;
 	struct _EMFormatCache *emfc;
+	GError *local_error = NULL;
 
 	/* should this perhaps run off a key of ".secured" ? */
 	emfc = g_hash_table_lookup(emf->inline_table, emf->part_id->str);
@@ -1368,39 +1354,45 @@ emf_application_xpkcs7mime(EMFormat *emf, CamelStream *stream, CamelMimePart *pa
 		return;
 	}
 
-	ex = camel_exception_new();
-
 	context = camel_smime_context_new(emf->session);
 
 	emf->validity_found |= EM_FORMAT_VALIDITY_FOUND_ENCRYPTED | EM_FORMAT_VALIDITY_FOUND_SMIME;
 
 	opart = camel_mime_part_new();
-	valid = camel_cipher_decrypt(context, part, opart, ex);
+	valid = camel_cipher_decrypt(context, part, opart, &local_error);
 	if (valid == NULL) {
-		em_format_format_error(emf, stream, "%s", ex->desc?ex->desc:_("Could not parse S/MIME message: Unknown error"));
+		em_format_format_error (
+			emf, stream, "%s",
+			local_error->message ? local_error->message :
+			_("Could not parse S/MIME message: Unknown error"));
+		g_clear_error (&local_error);
+
 		em_format_part_as(emf, stream, part, NULL);
 	} else {
 		if (emfc == NULL)
 			emfc = emf_insert_cache(emf, emf->part_id->str);
 
 		emfc->valid = camel_cipher_validity_clone(valid);
-		camel_object_ref((emfc->secured = opart));
+		g_object_ref ((emfc->secured = opart));
 
 		add_validity_found (emf, valid);
 		em_format_format_secure(emf, stream, opart, valid);
 	}
 
-	camel_object_unref(opart);
-	camel_object_unref(context);
-	camel_exception_free(ex);
+	g_object_unref (opart);
+	g_object_unref (context);
 }
 #endif
 
 /* RFC 1740 */
 static void
-emf_multipart_appledouble(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_multipart_appledouble (EMFormat *emf,
+                           CamelStream *stream,
+                           CamelMimePart *part,
+                           const EMFormatHandler *info,
+                           gboolean is_fallback)
 {
-	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
+	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content ((CamelMedium *)part);
 	CamelMimePart *mime_part;
 	gint len;
 
@@ -1423,9 +1415,13 @@ emf_multipart_appledouble(EMFormat *emf, CamelStream *stream, CamelMimePart *par
 
 /* RFC ??? */
 static void
-emf_multipart_mixed(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_multipart_mixed (EMFormat *emf,
+                     CamelStream *stream,
+                     CamelMimePart *part,
+                     const EMFormatHandler *info,
+                     gboolean is_fallback)
 {
-	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
+	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content ((CamelMedium *)part);
 	gint i, nparts, len;
 
 	if (!CAMEL_IS_MULTIPART(mp)) {
@@ -1445,9 +1441,13 @@ emf_multipart_mixed(EMFormat *emf, CamelStream *stream, CamelMimePart *part, con
 
 /* RFC 1740 */
 static void
-emf_multipart_alternative(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_multipart_alternative (EMFormat *emf,
+                           CamelStream *stream,
+                           CamelMimePart *part,
+                           const EMFormatHandler *info,
+                           gboolean is_fallback)
 {
-	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
+	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content ((CamelMedium *)part);
 	gint i, nparts, bestid = 0;
 	CamelMimePart *best = NULL;
 
@@ -1492,19 +1492,23 @@ emf_multipart_alternative(EMFormat *emf, CamelStream *stream, CamelMimePart *par
 		em_format_part(emf, stream, best);
 		g_string_truncate(emf->part_id, len);
 	} else
-		emf_multipart_mixed(emf, stream, part, info);
+		emf_multipart_mixed(emf, stream, part, info, is_fallback);
 }
 
 static void
-emf_multipart_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_multipart_encrypted (EMFormat *emf,
+                         CamelStream *stream,
+                         CamelMimePart *part,
+                         const EMFormatHandler *info,
+                         gboolean is_fallback)
 {
 	CamelCipherContext *context;
-	CamelException *ex;
 	const gchar *protocol;
 	CamelMimePart *opart;
 	CamelCipherValidity *valid;
 	CamelMultipartEncrypted *mpe;
 	struct _EMFormatCache *emfc;
+	GError *local_error = NULL;
 
 	/* should this perhaps run off a key of ".secured" ? */
 	emfc = g_hash_table_lookup(emf->inline_table, emf->part_id->str);
@@ -1513,7 +1517,7 @@ emf_multipart_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 		return;
 	}
 
-	mpe = (CamelMultipartEncrypted*)camel_medium_get_content_object((CamelMedium *)part);
+	mpe = (CamelMultipartEncrypted*)camel_medium_get_content ((CamelMedium *)part);
 	if (!CAMEL_IS_MULTIPART_ENCRYPTED(mpe)) {
 		em_format_format_error(emf, stream, _("Could not parse MIME message. Displaying as source."));
 		em_format_format_source(emf, stream, part);
@@ -1530,44 +1534,52 @@ emf_multipart_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 
 	emf->validity_found |= EM_FORMAT_VALIDITY_FOUND_ENCRYPTED | EM_FORMAT_VALIDITY_FOUND_PGP;
 
-	ex = camel_exception_new();
 	context = camel_gpg_context_new(emf->session);
 	opart = camel_mime_part_new();
-	valid = camel_cipher_decrypt(context, part, opart, ex);
+	valid = camel_cipher_decrypt(context, part, opart, &local_error);
 	if (valid == NULL) {
-		em_format_format_error(emf, stream, ex->desc?_("Could not parse PGP/MIME message"):_("Could not parse PGP/MIME message: Unknown error"));
-		if (ex->desc)
-			em_format_format_error(emf, stream, "%s", ex->desc);
+		em_format_format_error (
+			emf, stream, local_error->message ?
+			_("Could not parse PGP/MIME message") :
+			_("Could not parse PGP/MIME message: Unknown error"));
+		if (local_error->message != NULL)
+			em_format_format_error (
+				emf, stream, "%s", local_error->message);
+		g_clear_error (&local_error);
+
 		em_format_part_as(emf, stream, part, "multipart/mixed");
 	} else {
 		if (emfc == NULL)
 			emfc = emf_insert_cache(emf, emf->part_id->str);
 
 		emfc->valid = camel_cipher_validity_clone(valid);
-		camel_object_ref((emfc->secured = opart));
+		g_object_ref ((emfc->secured = opart));
 
 		add_validity_found (emf, valid);
 		em_format_format_secure(emf, stream, opart, valid);
 	}
 
 	/* TODO: Make sure when we finalize this part, it is zero'd out */
-	camel_object_unref(opart);
-	camel_object_unref(context);
-	camel_exception_free(ex);
+	g_object_unref (opart);
+	g_object_unref (context);
 }
 
 static void
 emf_write_related(EMFormat *emf, CamelStream *stream, EMFormatPURI *puri)
 {
 	em_format_format_content(emf, stream, puri->part);
-	camel_stream_close(stream);
+	camel_stream_close(stream, NULL);
 }
 
 /* RFC 2387 */
 static void
-emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_multipart_related (EMFormat *emf,
+                       CamelStream *stream,
+                       CamelMimePart *part,
+                       const EMFormatHandler *info,
+                       gboolean is_fallback)
 {
-	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)part);
+	CamelMultipart *mp = (CamelMultipart *)camel_medium_get_content ((CamelMedium *)part);
 	CamelMimePart *body_part, *display_part = NULL;
 	CamelContentType *content_type;
 	const gchar *start;
@@ -1607,7 +1619,7 @@ emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 	}
 
 	if (display_part == NULL) {
-		emf_multipart_mixed(emf, stream, part, info);
+		emf_multipart_mixed(emf, stream, part, info, is_fallback);
 		return;
 	}
 
@@ -1633,7 +1645,7 @@ emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 	g_string_append_printf(emf->part_id, ".related.%d", displayid);
 	em_format_part(emf, stream, display_part);
 	g_string_truncate(emf->part_id, partidlen);
-	camel_stream_flush(stream);
+	camel_stream_flush(stream, NULL);
 
 	link = g_queue_peek_head_link (emf->pending_uri_level->data);
 
@@ -1660,7 +1672,11 @@ emf_multipart_related(EMFormat *emf, CamelStream *stream, CamelMimePart *part, c
 }
 
 static void
-emf_multipart_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_multipart_signed (EMFormat *emf,
+                      CamelStream *stream,
+                      CamelMimePart *part,
+                      const EMFormatHandler *info,
+                      gboolean is_fallback)
 {
 	CamelMimePart *cpart;
 	CamelMultipartSigned *mps;
@@ -1674,7 +1690,7 @@ emf_multipart_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *part, co
 		return;
 	}
 
-	mps = (CamelMultipartSigned *)camel_medium_get_content_object((CamelMedium *)part);
+	mps = (CamelMultipartSigned *)camel_medium_get_content ((CamelMedium *)part);
 	if (!CAMEL_IS_MULTIPART_SIGNED(mps)
 	    || (cpart = camel_multipart_get_part((CamelMultipart *)mps, CAMEL_MULTIPART_SIGNED_CONTENT)) == NULL) {
 		em_format_format_error(emf, stream, _("Could not parse MIME message. Displaying as source."));
@@ -1704,28 +1720,34 @@ emf_multipart_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *part, co
 		em_format_format_error(emf, stream, _("Unsupported signature format"));
 		em_format_part_as(emf, stream, part, "multipart/mixed");
 	} else {
-		CamelException *ex = camel_exception_new();
 		CamelCipherValidity *valid;
+		GError *local_error = NULL;
 
-		valid = camel_cipher_verify(cipher, part, ex);
+		valid = camel_cipher_verify(cipher, part, &local_error);
 		if (valid == NULL) {
-			em_format_format_error(emf, stream, ex->desc?_("Error verifying signature"):_("Unknown error verifying signature"));
-			if (ex->desc)
-				em_format_format_error(emf, stream, "%s", ex->desc);
+			em_format_format_error (
+				emf, stream, local_error->message ?
+				_("Error verifying signature") :
+				_("Unknown error verifying signature"));
+			if (local_error->message != NULL)
+				em_format_format_error (
+					emf, stream, "%s",
+					local_error->message);
+			g_clear_error (&local_error);
+
 			em_format_part_as(emf, stream, part, "multipart/mixed");
 		} else {
 			if (emfc == NULL)
 				emfc = emf_insert_cache(emf, emf->part_id->str);
 
 			emfc->valid = camel_cipher_validity_clone(valid);
-			camel_object_ref((emfc->secured = cpart));
+			g_object_ref ((emfc->secured = cpart));
 
 			add_validity_found (emf, valid);
 			em_format_format_secure(emf, stream, cpart, valid);
 		}
 
-		camel_exception_free(ex);
-		camel_object_unref(cipher);
+		g_object_unref (cipher);
 	}
 }
 
@@ -1734,7 +1756,8 @@ static void
 emf_application_mbox (EMFormat *emf,
                       CamelStream *stream,
                       CamelMimePart *mime_part,
-                      const EMFormatHandler *info)
+                      const EMFormatHandler *info,
+                      gboolean is_fallback)
 {
 	const EMFormatHandler *handle;
 	CamelMimeParser *parser;
@@ -1763,11 +1786,12 @@ emf_application_mbox (EMFormat *emf,
 
 	mem_stream = camel_stream_mem_new ();
 	camel_data_wrapper_decode_to_stream (
-		camel_medium_get_content_object (CAMEL_MEDIUM (mime_part)), mem_stream);
+		camel_medium_get_content (CAMEL_MEDIUM (mime_part)),
+		mem_stream, NULL);
 	camel_seekable_stream_seek (
-		CAMEL_SEEKABLE_STREAM (mem_stream), 0, CAMEL_STREAM_SET);
-	camel_mime_parser_init_with_stream (parser, mem_stream);
-	camel_object_unref (mem_stream);
+		CAMEL_SEEKABLE_STREAM (mem_stream), 0, CAMEL_STREAM_SET, NULL);
+	camel_mime_parser_init_with_stream (parser, mem_stream, NULL);
+	g_object_unref (mem_stream);
 
 	/* Extract messages from the mbox. */
 	state = camel_mime_parser_step (parser, NULL, NULL);
@@ -1777,15 +1801,15 @@ emf_application_mbox (EMFormat *emf,
 		message = camel_mime_message_new ();
 		mime_part = CAMEL_MIME_PART (message);
 
-		if (camel_mime_part_construct_from_parser (mime_part, parser) == -1) {
-			camel_object_unref (message);
+		if (camel_mime_part_construct_from_parser (mime_part, parser, NULL) == -1) {
+			g_object_unref (message);
 			break;
 		}
 
 		/* Render the message. */
-		handle->handler (emf, stream, mime_part, handle);
+		handle->handler (emf, stream, mime_part, handle, FALSE);
 
-		camel_object_unref (message);
+		g_object_unref (message);
 
 		/* Skip past CAMEL_MIME_PARSER_STATE_FROM_END. */
 		camel_mime_parser_step (parser, NULL, NULL);
@@ -1793,13 +1817,17 @@ emf_application_mbox (EMFormat *emf,
 		state = camel_mime_parser_step (parser, NULL, NULL);
 	}
 
-	camel_object_unref (parser);
+	g_object_unref (parser);
 }
 
 static void
-emf_message_rfc822(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_message_rfc822 (EMFormat *emf,
+                    CamelStream *stream,
+                    CamelMimePart *part,
+                    const EMFormatHandler *info,
+                    gboolean is_fallback)
 {
-	CamelDataWrapper *dw = camel_medium_get_content_object((CamelMedium *)part);
+	CamelDataWrapper *dw = camel_medium_get_content ((CamelMedium *)part);
 	const EMFormatHandler *handle;
 	gint len;
 
@@ -1813,13 +1841,17 @@ emf_message_rfc822(EMFormat *emf, CamelStream *stream, CamelMimePart *part, cons
 
 	handle = em_format_find_handler(emf, "x-evolution/message/rfc822");
 	if (handle)
-		handle->handler(emf, stream, (CamelMimePart *)dw, handle);
+		handle->handler(emf, stream, (CamelMimePart *)dw, handle, FALSE);
 
 	g_string_truncate(emf->part_id, len);
 }
 
 static void
-emf_message_deliverystatus(EMFormat *emf, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info)
+emf_message_deliverystatus (EMFormat *emf,
+                            CamelStream *stream,
+                            CamelMimePart *part,
+                            const EMFormatHandler *info,
+                            gboolean is_fallback)
 {
 	em_format_format_text(emf, stream, (CamelDataWrapper *)part);
 }
@@ -1827,7 +1859,7 @@ emf_message_deliverystatus(EMFormat *emf, CamelStream *stream, CamelMimePart *pa
 static void
 emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, EMFormatHandler *info)
 {
-	CamelStreamFilter *filtered_stream;
+	CamelStream *filtered_stream;
 	CamelMimeFilterPgp *pgp_filter;
 	CamelContentType *content_type;
 	CamelCipherContext *cipher;
@@ -1835,8 +1867,8 @@ emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, E
 	CamelDataWrapper *dw;
 	CamelMimePart *opart;
 	CamelStream *ostream;
-	CamelException *ex;
 	gchar *type;
+	GError *local_error = NULL;
 
 	if (!ipart) {
 		em_format_format_error(emf, stream, _("Unknown error verifying signature"));
@@ -1845,35 +1877,41 @@ emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, E
 
 	emf->validity_found |= EM_FORMAT_VALIDITY_FOUND_SIGNED | EM_FORMAT_VALIDITY_FOUND_PGP;
 
-	ex = camel_exception_new();
 	cipher = camel_gpg_context_new(emf->session);
 	/* Verify the signature of the message */
-	valid = camel_cipher_verify(cipher, ipart, ex);
+	valid = camel_cipher_verify(cipher, ipart, &local_error);
 	if (!valid) {
-		em_format_format_error(emf, stream, ex->desc?_("Error verifying signature"):_("Unknown error verifying signature"));
-		if (ex->desc)
-			em_format_format_error(emf, stream, "%s", ex->desc);
+		em_format_format_error (
+			emf, stream, local_error->message ?
+			_("Error verifying signature") :
+			_("Unknown error verifying signature"));
+		if (local_error->message)
+			em_format_format_error (
+				emf, stream, "%s", local_error->message);
 		em_format_format_source(emf, stream, ipart);
 		/* I think this will loop: em_format_part_as(emf, stream, part, "text/plain"); */
-		camel_exception_free(ex);
-		camel_object_unref(cipher);
+		g_clear_error (&local_error);
+		g_object_unref (cipher);
 		return;
 	}
 
 	/* Setup output stream */
 	ostream = camel_stream_mem_new();
-	filtered_stream = camel_stream_filter_new_with_stream(ostream);
+	filtered_stream = camel_stream_filter_new (ostream);
 
 	/* Add PGP header / footer filter */
 	pgp_filter = (CamelMimeFilterPgp *)camel_mime_filter_pgp_new();
-	camel_stream_filter_add(filtered_stream, (CamelMimeFilter *)pgp_filter);
-	camel_object_unref(pgp_filter);
+	camel_stream_filter_add (
+		CAMEL_STREAM_FILTER (filtered_stream),
+		CAMEL_MIME_FILTER (pgp_filter));
+	g_object_unref (pgp_filter);
 
 	/* Pass through the filters that have been setup */
-	dw = camel_medium_get_content_object((CamelMedium *)ipart);
-	camel_data_wrapper_decode_to_stream(dw, (CamelStream *)filtered_stream);
-	camel_stream_flush((CamelStream *)filtered_stream);
-	camel_object_unref(filtered_stream);
+	dw = camel_medium_get_content ((CamelMedium *)ipart);
+	camel_data_wrapper_decode_to_stream (
+		dw, (CamelStream *)filtered_stream, NULL);
+	camel_stream_flush((CamelStream *)filtered_stream, NULL);
+	g_object_unref (filtered_stream);
 
 	/* Create a new text/plain MIME part containing the signed content preserving the original part's Content-Type params */
 	content_type = camel_mime_part_get_content_type (ipart);
@@ -1889,12 +1927,12 @@ emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, E
 	camel_content_type_unref (content_type);
 
 	dw = camel_data_wrapper_new ();
-	camel_data_wrapper_construct_from_stream (dw, ostream);
+	camel_data_wrapper_construct_from_stream (dw, ostream, NULL);
 	camel_data_wrapper_set_mime_type (dw, type);
 	g_free (type);
 
 	opart = camel_mime_part_new ();
-	camel_medium_set_content_object ((CamelMedium *) opart, dw);
+	camel_medium_set_content ((CamelMedium *) opart, dw);
 	camel_data_wrapper_set_mime_type_field ((CamelDataWrapper *) opart, dw->mime_type);
 
 	add_validity_found (emf, valid);
@@ -1902,11 +1940,10 @@ emf_inlinepgp_signed(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart, E
 	em_format_format_secure(emf, stream, opart, valid);
 
 	/* Clean Up */
-	camel_object_unref(dw);
-	camel_object_unref(opart);
-	camel_object_unref(ostream);
-	camel_object_unref(cipher);
-	camel_exception_free(ex);
+	g_object_unref (dw);
+	g_object_unref (opart);
+	g_object_unref (ostream);
+	g_object_unref (cipher);
 }
 
 static void
@@ -1914,31 +1951,36 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 {
 	CamelCipherContext *cipher;
 	CamelCipherValidity *valid;
-	CamelException *ex;
 	CamelMimePart *opart;
 	CamelDataWrapper *dw;
 	gchar *mime_type;
+	GError *local_error = NULL;
 
 	emf->validity_found |= EM_FORMAT_VALIDITY_FOUND_ENCRYPTED | EM_FORMAT_VALIDITY_FOUND_PGP;
 
 	cipher = camel_gpg_context_new(emf->session);
-	ex = camel_exception_new();
 	opart = camel_mime_part_new();
 	/* Decrypt the message */
-	valid = camel_cipher_decrypt (cipher, ipart, opart, ex);
+	valid = camel_cipher_decrypt (cipher, ipart, opart, &local_error);
 	if (!valid) {
-		em_format_format_error(emf, stream, ex->desc?_("Could not parse PGP message"):_("Could not parse PGP message: Unknown error"));
-		if (ex->desc)
-			em_format_format_error(emf, stream, "%s", ex->desc);
+		em_format_format_error (
+			emf, stream, _("Could not parse PGP message: "));
+		if (local_error->message != NULL)
+			em_format_format_error (
+				emf, stream, "%s", local_error->message);
+		else
+			em_format_format_error (
+				emf, stream, _("Unknown error"));
 		em_format_format_source(emf, stream, ipart);
 		/* I think this will loop: em_format_part_as(emf, stream, part, "text/plain"); */
-		camel_exception_free(ex);
-		camel_object_unref(cipher);
-		camel_object_unref(opart);
+
+		g_clear_error (&local_error);
+		g_object_unref (cipher);
+		g_object_unref (opart);
 		return;
 	}
 
-	dw = camel_medium_get_content_object ((CamelMedium *)opart);
+	dw = camel_medium_get_content ((CamelMedium *)opart);
 	mime_type = camel_data_wrapper_get_mime_type (dw);
 
 	/* this ensures to show the 'opart' as inlined, if possible */
@@ -1956,9 +1998,8 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 	em_format_format_secure(emf, stream, opart, valid);
 
 	/* Clean Up */
-	camel_object_unref(opart);
-	camel_object_unref (cipher);
-	camel_exception_free (ex);
+	g_object_unref (opart);
+	g_object_unref (cipher);
 }
 
 static EMFormatHandler type_builtin_table[] = {
@@ -2019,20 +2060,28 @@ em_format_snoop_type (CamelMimePart *part)
 	if (filename != NULL)
 		name_type = e_util_guess_mime_type (filename, FALSE);
 
-	dw = camel_medium_get_content_object((CamelMedium *)part);
-	if (!camel_data_wrapper_is_offline(dw)) {
-		GByteArray *buffer = g_byte_array_new ();
-		CamelStreamMem *mem = (CamelStreamMem *)camel_stream_mem_new_with_byte_array(buffer);
+	dw = camel_medium_get_content ((CamelMedium *)part);
+	if (!camel_data_wrapper_is_offline (dw)) {
+		GByteArray *byte_array;
+		CamelStream *stream;
 
-		if (camel_data_wrapper_decode_to_stream(dw, (CamelStream *)mem) > 0) {
-			gchar *ct = g_content_type_guess (filename, buffer->data, buffer->len, NULL);
+		byte_array = g_byte_array_new ();
+		stream = camel_stream_mem_new_with_byte_array (byte_array);
 
-			if (ct)
-				magic_type = g_content_type_get_mime_type (ct);
+		if (camel_data_wrapper_decode_to_stream (dw, stream, NULL) > 0) {
+			gchar *content_type;
 
-			g_free (ct);
+			content_type = g_content_type_guess (
+				filename, byte_array->data,
+				byte_array->len, NULL);
+
+			if (content_type != NULL)
+				magic_type = g_content_type_get_mime_type (content_type);
+
+			g_free (content_type);
 		}
-		camel_object_unref(mem);
+
+		g_object_unref (stream);
 	}
 
 	d(printf("snooped part, magic_type '%s' name_type '%s'\n", magic_type, name_type));
