@@ -29,13 +29,7 @@
 #define EM_FORMAT_H
 
 #include <glib-object.h>
-#include <camel/camel-url.h>
-#include <camel/camel-folder.h>
-#include <camel/camel-stream.h>
-#include <camel/camel-session.h>
-#include <camel/camel-mime-part.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-cipher-context.h>
+#include <camel/camel.h>
 
 /* Standard GObject macros */
 #define EM_TYPE_FORMAT \
@@ -65,7 +59,7 @@ typedef struct _EMFormatPrivate EMFormatPrivate;
 typedef struct _EMFormatHandler EMFormatHandler;
 typedef struct _EMFormatHeader EMFormatHeader;
 
-typedef void (*EMFormatFunc) (EMFormat *md, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info);
+typedef void (*EMFormatFunc) (EMFormat *md, CamelStream *stream, CamelMimePart *part, const EMFormatHandler *info, gboolean is_fallback);
 
 typedef enum _em_format_mode_t {
 	EM_FORMAT_NORMAL,
@@ -255,7 +249,7 @@ struct _EMFormatClass {
 	gboolean (*busy)(EMFormat *);
 
 	/* Shows optional way to open messages  */
-	void (*format_optional)(EMFormat *, CamelStream *, CamelMimePart *, const GByteArray *mem_bytes);
+	void (*format_optional)(EMFormat *, CamelStream *, CamelMimePart *, CamelStream* );
 
 	/* signals */
 	/* complete, alternative to polling busy, for asynchronous work */
