@@ -23,7 +23,6 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <camel/camel-folder.h>
 
 #include "e-util/e-util.h"
 #include "e-util/e-plugin-ui.h"
@@ -50,7 +49,7 @@ struct _EMailBrowserPrivate {
 	EFocusTracker *focus_tracker;
 	EShellBackend *shell_backend;
 	GtkActionGroup *action_group;
-	EMFormatHTMLDisplay *html_display;
+	EMFormatHTMLDisplay *formatter;
 
 	GtkWidget *main_menu;
 	GtkWidget *main_toolbar;
@@ -64,6 +63,7 @@ struct _EMailBrowserPrivate {
 enum {
 	PROP_0,
 	PROP_FOCUS_TRACKER,
+	PROP_GROUP_BY_THREADS,
 	PROP_SHELL_BACKEND,
 	PROP_SHOW_DELETED,
 	PROP_UI_MANAGER
@@ -240,10 +240,11 @@ static void
 mail_browser_message_selected_cb (EMailBrowser *browser,
                                   const gchar *uid)
 {
-	EMFormatHTMLDisplay *html_display;
+	EMFormatHTML *formatter;
 	CamelMessageInfo *info;
 	CamelFolder *folder;
 	EMailReader *reader;
+	EWebView *web_view;
 	const gchar *title;
 
 	if (uid == NULL)
@@ -251,23 +252,20 @@ mail_browser_message_selected_cb (EMailBrowser *browser,
 
 	reader = E_MAIL_READER (browser);
 	folder = e_mail_reader_get_folder (reader);
-	html_display = e_mail_reader_get_html_display (reader);
+	formatter = e_mail_reader_get_formatter (reader);
+	web_view = em_format_html_get_web_view (formatter);
 
 	info = camel_folder_get_message_info (folder, uid);
 
 	if (info == NULL)
 		return;
 
-	/* XXX The string here was added after the 2.30.0 release, so
-	 *     it's not marked for translation.  But it IS marked for
-	 *     translation in 2.31. */
 	title = camel_message_info_subject (info);
 	if (title == NULL || *title == '\0')
-		title = "(No Subject)";
+		title = _("(No Subject)");
 
 	gtk_window_set_title (GTK_WINDOW (browser), title);
-	gtk_widget_grab_focus (
-		GTK_WIDGET (((EMFormatHTML *) html_display)->html));
+	gtk_widget_grab_focus (GTK_WIDGET (web_view));
 
 	camel_folder_free_message_info (folder, info);
 }
@@ -297,6 +295,7 @@ mail_browser_popup_event_cb (EMailBrowser *browser,
 {
 	EMailReader *reader;
 	GtkMenu *menu;
+	guint32 state;
 
 	if (uri != NULL)
 		return FALSE;
@@ -304,7 +303,8 @@ mail_browser_popup_event_cb (EMailBrowser *browser,
 	reader = E_MAIL_READER (browser);
 	menu = e_mail_reader_get_popup_menu (reader);
 
-	e_mail_reader_update_actions (reader);
+	state = e_mail_reader_check_state (reader);
+	e_mail_reader_update_actions (reader, state);
 
 	if (event == NULL)
 		gtk_menu_popup (
@@ -351,6 +351,12 @@ mail_browser_set_property (GObject *object,
                            GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_GROUP_BY_THREADS:
+			e_mail_reader_set_group_by_threads (
+				E_MAIL_READER (object),
+				g_value_get_boolean (value));
+			return;
+
 		case PROP_SHELL_BACKEND:
 			mail_browser_set_shell_backend (
 				E_MAIL_BROWSER (object),
@@ -380,6 +386,12 @@ mail_browser_get_property (GObject *object,
 				E_MAIL_BROWSER (object)));
 			return;
 
+		case PROP_GROUP_BY_THREADS:
+			g_value_set_boolean (
+				value, e_mail_reader_get_group_by_threads (
+				E_MAIL_READER (object)));
+			return;
+
 		case PROP_SHELL_BACKEND:
 			g_value_set_object (
 				value, e_mail_reader_get_shell_backend (
@@ -429,9 +441,9 @@ mail_browser_dispose (GObject *object)
 		priv->action_group = NULL;
 	}
 
-	if (priv->html_display != NULL) {
-		g_object_unref (priv->html_display);
-		priv->html_display = NULL;
+	if (priv->formatter != NULL) {
+		g_object_unref (priv->formatter);
+		priv->formatter = NULL;
 	}
 
 	if (priv->main_menu != NULL) {
@@ -467,8 +479,8 @@ mail_browser_dispose (GObject *object)
 static void
 mail_browser_constructed (GObject *object)
 {
-	EMFormatHTMLDisplay *html_display;
 	EMailBrowserPrivate *priv;
+	EMFormatHTML *formatter;
 	EMailReader *reader;
 	EShellBackend *shell_backend;
 	EShell *shell;
@@ -504,10 +516,10 @@ mail_browser_constructed (GObject *object)
 	priv->ui_manager = ui_manager;
 	domain = GETTEXT_PACKAGE;
 
-	html_display = e_mail_reader_get_html_display (reader);
+	formatter = e_mail_reader_get_formatter (reader);
 	e_shell_watch_window (shell, GTK_WINDOW (object));
 
-	web_view = E_WEB_VIEW (EM_FORMAT_HTML (html_display)->html);
+	web_view = em_format_html_get_web_view (formatter);
 
 	/* The message list is a widget, but it is not shown in the browser.
 	 * Unfortunately, the widget is inseparable from its model, and the
@@ -606,7 +618,7 @@ mail_browser_constructed (GObject *object)
 
 	g_signal_connect_swapped (
 		search_bar, "changed",
-		G_CALLBACK (em_format_redraw), priv->html_display);
+		G_CALLBACK (em_format_redraw), priv->formatter);
 
 	/* Bind GObject properties to GConf keys. */
 
@@ -657,14 +669,14 @@ mail_browser_get_hide_deleted (EMailReader *reader)
 	return !e_mail_browser_get_show_deleted (browser);
 }
 
-static EMFormatHTMLDisplay *
-mail_browser_get_html_display (EMailReader *reader)
+static EMFormatHTML *
+mail_browser_get_formatter (EMailReader *reader)
 {
 	EMailBrowserPrivate *priv;
 
 	priv = E_MAIL_BROWSER_GET_PRIVATE (reader);
 
-	return priv->html_display;
+	return EM_FORMAT_HTML (priv->formatter);
 }
 
 static GtkWidget *
@@ -768,18 +780,24 @@ mail_browser_class_init (EMailBrowserClass *class)
 		PROP_FOCUS_TRACKER,
 		g_param_spec_object (
 			"focus-tracker",
-			_("Focus Tracker"),
+			"Focus Tracker",
 			NULL,
 			E_TYPE_FOCUS_TRACKER,
 			G_PARAM_READABLE));
 
+	/* Inherited from EMailReader */
+	g_object_class_override_property (
+		object_class,
+		PROP_GROUP_BY_THREADS,
+		"group-by-threads");
+
 	g_object_class_install_property (
 		object_class,
 		PROP_SHELL_BACKEND,
 		g_param_spec_object (
 			"shell-backend",
-			_("Shell Module"),
-			_("The mail shell backend"),
+			"Shell Module",
+			"The mail shell backend",
 			E_TYPE_SHELL_BACKEND,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT_ONLY));
@@ -789,8 +807,8 @@ mail_browser_class_init (EMailBrowserClass *class)
 		PROP_SHOW_DELETED,
 		g_param_spec_boolean (
 			"show-deleted",
-			_("Show Deleted"),
-			_("Show deleted messages"),
+			"Show Deleted",
+			"Show deleted messages",
 			FALSE,
 			G_PARAM_READWRITE));
 }
@@ -799,8 +817,8 @@ static void
 mail_browser_iface_init (EMailReaderIface *iface)
 {
 	iface->get_action_group = mail_browser_get_action_group;
+	iface->get_formatter = mail_browser_get_formatter;
 	iface->get_hide_deleted = mail_browser_get_hide_deleted;
-	iface->get_html_display = mail_browser_get_html_display;
 	iface->get_message_list = mail_browser_get_message_list;
 	iface->get_popup_menu = mail_browser_get_popup_menu;
 	iface->get_shell_backend = mail_browser_get_shell_backend;
@@ -818,7 +836,7 @@ mail_browser_init (EMailBrowser *browser)
 	browser->priv = E_MAIL_BROWSER_GET_PRIVATE (browser);
 
 	browser->priv->action_group = gtk_action_group_new ("mail-browser");
-	browser->priv->html_display = em_format_html_display_new ();
+	browser->priv->formatter = em_format_html_display_new ();
 
 	bridge = gconf_bridge_get ();
 	prefix = "/apps/evolution/mail/mail_browser";
