@@ -30,7 +30,6 @@
 G_BEGIN_DECLS
 
 void em_utils_compose_new_message (const gchar *fromuri);
-EMsgComposer * em_utils_compose_lite_new_message (const gchar *fromuri);
 
 /* FIXME: mailto?  url?  should make up its mind what its called.  imho use 'uri' */
 EMsgComposer * em_utils_compose_new_message_with_mailto (const gchar *url, const gchar *fromuri);
@@ -48,7 +47,7 @@ void em_utils_forward_messages (CamelFolder *folder, GPtrArray *uids, const gcha
 void em_utils_redirect_message (CamelMimeMessage *message);
 void em_utils_redirect_message_by_uid (CamelFolder *folder, const gchar *uid);
 
-void em_utils_forward_message_raw (CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex);
+void em_utils_forward_message_raw (CamelFolder *folder, CamelMimeMessage *message, const gchar *address, GError **error);
 
 void em_utils_handle_receipt (CamelFolder *folder, const gchar *uid, CamelMimeMessage *msg);
 void em_utils_send_receipt   (CamelFolder *folder, CamelMimeMessage *message);
