@@ -39,20 +39,12 @@
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
-#include <camel/camel-session.h>
-#include <camel/camel-store.h>
-#include <camel/camel-folder.h>
-#include <camel/camel-vee-store.h>
-#include <camel/camel-vtrash-folder.h>
-#include <camel/camel-stream-mem.h>
-#include <camel/camel-file-utils.h>
-#include <camel/camel-stream-fs.h>
-
 #include "e-util/e-account-utils.h"
 #include "e-util/e-mktemp.h"
 #include "e-util/e-icon-factory.h"
 #include "e-util/e-alert-dialog.h"
 #include "e-util/e-util.h"
+#include "e-util/gtk-compat.h"
 
 #include "misc/e-selectable.h"
 
@@ -199,7 +191,8 @@ folder_tree_get_folder_info__exec (struct _EMFolderTreeGetFolderInfo *m)
 {
 	guint32 flags = m->flags | CAMEL_STORE_FOLDER_INFO_SUBSCRIBED;
 
-	m->fi = camel_store_get_folder_info (m->store, m->top, flags, &m->base.ex);
+	m->fi = camel_store_get_folder_info (
+		m->store, m->top, flags, &m->base.error);
 }
 
 static void
@@ -234,7 +227,7 @@ folder_tree_get_folder_info__done (struct _EMFolderTreeGetFolderInfo *m)
 	gtk_tree_model_get_iter (model, &root, path);
 
 	/* if we had an error, then we need to re-set the load subdirs state and collapse the node */
-	if (!m->fi && camel_exception_is_set(&m->base.ex)) {
+	if (!m->fi && m->base.error != NULL) {
 		gtk_tree_store_set(
 			GTK_TREE_STORE (model), &root,
 			COL_BOOL_LOAD_SUBDIRS, TRUE, -1);
@@ -326,7 +319,7 @@ folder_tree_get_folder_info__free (struct _EMFolderTreeGetFolderInfo *m)
 
 	gtk_tree_row_reference_free (m->root);
 	g_object_unref(m->folder_tree);
-	camel_object_unref (m->store);
+	g_object_unref (m->store);
 	g_free (m->top);
 }
 
@@ -350,7 +343,7 @@ folder_tree_free_select_uri (struct _selected_uri *u)
 {
 	g_free (u->uri);
 	if (u->store)
-		camel_object_unref (u->store);
+		g_object_unref (u->store);
 	g_free (u->key);
 	g_free (u->path);
 	g_free (u);
@@ -448,11 +441,9 @@ folder_tree_expand_node (const gchar *key,
 	model = gtk_tree_view_get_model (tree_view);
 
 	if ((account = e_get_account_by_uid (uid)) && account->enabled) {
-		CamelException ex;
-
-		camel_exception_init (&ex);
-		store = (CamelStore *) camel_session_get_service (session, account->source->url, CAMEL_PROVIDER_STORE, &ex);
-		camel_exception_clear (&ex);
+		store = (CamelStore *) camel_session_get_service (
+			session, account->source->url,
+			CAMEL_PROVIDER_STORE, NULL);
 
 		if (store == NULL)
 			return;
@@ -460,12 +451,12 @@ folder_tree_expand_node (const gchar *key,
 		if (!(store = vfolder_store))
 			return;
 
-		camel_object_ref (store);
+		g_object_ref (store);
 	} else if (!strcmp (uid, "local")) {
 		if (!(store = e_mail_local_get_store ()))
 			return;
 
-		camel_object_ref (store);
+		g_object_ref (store);
 	} else {
 		return;
 	}
@@ -473,11 +464,11 @@ folder_tree_expand_node (const gchar *key,
 	si = em_folder_tree_model_lookup_store_info (
 		EM_FOLDER_TREE_MODEL (model), store);
 	if (si == NULL) {
-		camel_object_unref (store);
+		g_object_unref (store);
 		return;
 	}
 
-	camel_object_unref (store);
+	g_object_unref (store);
 
 	if (p != NULL) {
 		if (!(row = g_hash_table_lookup (si->full_hash, p + 1)))
@@ -560,7 +551,6 @@ folder_tree_cell_edited_cb (EMFolderTree *folder_tree,
                             const gchar *new_name)
 {
 	CamelFolderInfo *folder_info;
-	CamelException ex;
 	CamelStore *store;
 	GtkTreeView *tree_view;
 	GtkTreeModel *model;
@@ -572,13 +562,12 @@ folder_tree_cell_edited_cb (EMFolderTree *folder_tree,
 	gchar **strv;
 	gpointer parent;
 	guint index;
+	GError *local_error = NULL;
 
 	/* XXX Consider splitting this into separate async functions:
 	 *     em_folder_tree_rename_folder_async()
 	 *     em_folder_tree_rename_folder_finish() */
 
-	camel_exception_init (&ex);
-
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (folder_tree));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
 
@@ -616,7 +605,7 @@ folder_tree_cell_edited_cb (EMFolderTree *folder_tree,
 
 	/* Check for duplicate folder name. */
 	folder_info = camel_store_get_folder_info (
-		store, new_full_name, CAMEL_STORE_FOLDER_INFO_FAST, &ex);
+		store, new_full_name, CAMEL_STORE_FOLDER_INFO_FAST, NULL);
 	if (folder_info != NULL) {
 		e_alert_run_dialog_for_args (
 			parent, "mail:no-rename-folder-exists",
@@ -626,16 +615,17 @@ folder_tree_cell_edited_cb (EMFolderTree *folder_tree,
 	}
 
 	/* XXX This needs to be asynchronous. */
-	camel_store_rename_folder (store, old_full_name, new_full_name, &ex);
-	if (camel_exception_is_set (&ex)) {
+	if (!camel_store_rename_folder (
+		store, old_full_name, new_full_name, &local_error)) {
 		e_alert_run_dialog_for_args (
 			parent, "mail:no-rename-folder",
-			old_full_name, new_full_name, ex.desc, NULL);
+			old_full_name, new_full_name,
+			local_error->message, NULL);
+		g_clear_error (&local_error);
 		goto exit;
 	}
 
 exit:
-	camel_exception_clear (&ex);
 
 	g_free (old_name);
 	g_free (old_full_name);
@@ -932,7 +922,7 @@ folder_tree_row_expanded (GtkTreeView *tree_view,
 
 	msg = mail_msg_new (&get_folder_info_info);
 	msg->root = gtk_tree_row_reference_new (model, path);
-	camel_object_ref (store);
+	g_object_ref (store);
 	msg->store = store;
 	msg->folder_tree = g_object_ref (tree_view);
 	msg->top = full_name;
@@ -1188,7 +1178,7 @@ folder_tree_new (EMFolderTree *folder_tree)
 
 	/* FIXME Gross hack */
 	tree = GTK_WIDGET (folder_tree);
-	GTK_WIDGET_SET_FLAGS(tree, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (tree, TRUE);
 
 	folder_tree->priv->selectable = NULL;
 
@@ -1440,7 +1430,9 @@ em_folder_tree_new (void)
 }
 
 static void
-tree_drag_begin (GtkWidget *widget, GdkDragContext *context, EMFolderTree *folder_tree)
+tree_drag_begin (GtkWidget *widget,
+                 GdkDragContext *context,
+                 EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	GtkTreeSelection *selection;
@@ -1467,7 +1459,9 @@ tree_drag_begin (GtkWidget *widget, GdkDragContext *context, EMFolderTree *folde
 }
 
 static void
-tree_drag_data_delete(GtkWidget *widget, GdkDragContext *context, EMFolderTree *folder_tree)
+tree_drag_data_delete (GtkWidget *widget,
+                       GdkDragContext *context,
+                       EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	gchar *full_name = NULL;
@@ -1475,7 +1469,6 @@ tree_drag_data_delete(GtkWidget *widget, GdkDragContext *context, EMFolderTree *
 	GtkTreePath *src_path;
 	gboolean is_store;
 	CamelStore *store;
-	CamelException ex;
 	GtkTreeIter iter;
 
 	if (!priv->drag_row || (src_path = gtk_tree_row_reference_get_path (priv->drag_row)))
@@ -1495,17 +1488,20 @@ tree_drag_data_delete(GtkWidget *widget, GdkDragContext *context, EMFolderTree *
 	if (is_store)
 		goto fail;
 
-	camel_exception_init(&ex);
-	camel_store_delete_folder(store, full_name, &ex);
-	if (camel_exception_is_set(&ex))
-		camel_exception_clear(&ex);
+	camel_store_delete_folder(store, full_name, NULL);
+
 fail:
 	gtk_tree_path_free(src_path);
 	g_free (full_name);
 }
 
 static void
-tree_drag_data_get(GtkWidget *widget, GdkDragContext *context, GtkSelectionData *selection, guint info, guint time, EMFolderTree *folder_tree)
+tree_drag_data_get (GtkWidget *widget,
+                    GdkDragContext *context,
+                    GtkSelectionData *selection,
+                    guint info,
+                    guint time,
+                    EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	gchar *full_name = NULL, *uri = NULL;
@@ -1513,7 +1509,6 @@ tree_drag_data_get(GtkWidget *widget, GdkDragContext *context, GtkSelectionData
 	GtkTreePath *src_path;
 	CamelFolder *folder;
 	CamelStore *store;
-	CamelException ex;
 	GtkTreeIter iter;
 
 	if (!priv->drag_row || !(src_path = gtk_tree_row_reference_get_path(priv->drag_row)))
@@ -1534,8 +1529,6 @@ tree_drag_data_get(GtkWidget *widget, GdkDragContext *context, GtkSelectionData
 	if (full_name == NULL)
 		goto fail;
 
-	camel_exception_init(&ex);
-
 	switch (info) {
 	case DND_DRAG_TYPE_FOLDER:
 		/* dragging to a new location in the folder tree */
@@ -1543,20 +1536,18 @@ tree_drag_data_get(GtkWidget *widget, GdkDragContext *context, GtkSelectionData
 		break;
 	case DND_DRAG_TYPE_TEXT_URI_LIST:
 		/* dragging to nautilus or something, probably */
-		if ((folder = camel_store_get_folder(store, full_name, 0, &ex))) {
+		if ((folder = camel_store_get_folder(store, full_name, 0, NULL))) {
 			GPtrArray *uids = camel_folder_get_uids(folder);
 
 			em_utils_selection_set_urilist(selection, folder, uids);
 			camel_folder_free_uids(folder, uids);
-			camel_object_unref(folder);
+			g_object_unref (folder);
 		}
 		break;
 	default:
 		abort();
 	}
 
-	if (camel_exception_is_set(&ex))
-		camel_exception_clear(&ex);
 fail:
 	gtk_tree_path_free(src_path);
 	g_free (full_name);
@@ -1587,25 +1578,39 @@ struct _DragDataReceivedAsync {
 static void
 folder_tree_drop_folder(struct _DragDataReceivedAsync *m)
 {
-	CamelFolder *src;
+	CamelFolder *folder;
+	CamelStore *parent_store;
+	const gchar *full_name;
+	const guchar *data;
 
-	d(printf(" * Drop folder '%s' onto '%s'\n", m->selection->data, m->full_name));
+	data = gtk_selection_data_get_data (m->selection);
 
-	if (!(src = mail_tool_uri_to_folder((gchar *)m->selection->data, 0, &m->base.ex)))
+	d(printf(" * Drop folder '%s' onto '%s'\n", data, m->full_name));
+
+	if (!(folder = mail_tool_uri_to_folder((gchar *)data, 0, &m->base.error)))
 		return;
 
-	em_folder_utils_copy_folders(src->parent_store, src->full_name, m->store, m->full_name?m->full_name:"", m->move);
-	camel_object_unref(src);
+	full_name = camel_folder_get_full_name (folder);
+	parent_store = camel_folder_get_parent_store (folder);
+
+	em_folder_utils_copy_folders (
+		parent_store, full_name, m->store,
+		m->full_name ? m->full_name : "", m->move);
+
+	g_object_unref (folder);
 }
 
 static gchar *
 folder_tree_drop_async__desc (struct _DragDataReceivedAsync *m)
 {
 	CamelURL *url;
+	const guchar *data;
 	gchar *buf;
 
+	data = gtk_selection_data_get_data (m->selection);
+
 	if (m->info == DND_DROP_TYPE_FOLDER) {
-		url = camel_url_new ((gchar *)m->selection->data, NULL);
+		url = camel_url_new ((gchar *)data, NULL);
 
 		if (m->move)
 			buf = g_strdup_printf (_("Moving folder %s"), url->fragment ? url->fragment : url->path + 1);
@@ -1633,14 +1638,15 @@ folder_tree_drop_async__exec (struct _DragDataReceivedAsync *m)
 		/* copy or move (aka rename) a folder */
 		folder_tree_drop_folder(m);
 	} else if (m->full_name == NULL) {
-		camel_exception_set (&m->base.ex, CAMEL_EXCEPTION_SYSTEM,
-				     _("Cannot drop message(s) into toplevel store"));
-	} else if ((folder = camel_store_get_folder (m->store, m->full_name, 0, &m->base.ex))) {
+		g_set_error (
+			&m->base.error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Cannot drop message(s) into toplevel store"));
+	} else if ((folder = camel_store_get_folder (m->store, m->full_name, 0, &m->base.error))) {
 		switch (m->info) {
 		case DND_DROP_TYPE_UID_LIST:
 			/* import a list of uids from another evo folder */
-			em_utils_selection_get_uidlist(m->selection, folder, m->move, &m->base.ex);
-			m->moved = m->move && !camel_exception_is_set(&m->base.ex);
+			em_utils_selection_get_uidlist(m->selection, folder, m->move, &m->base.error);
+			m->moved = m->move && (m->base.error == NULL);
 			break;
 		case DND_DROP_TYPE_MESSAGE_RFC822:
 			/* import a message/rfc822 stream */
@@ -1653,7 +1659,7 @@ folder_tree_drop_async__exec (struct _DragDataReceivedAsync *m)
 		default:
 			abort();
 		}
-		camel_object_unref(folder);
+		g_object_unref (folder);
 	}
 }
 
@@ -1661,7 +1667,7 @@ static void
 folder_tree_drop_async__free (struct _DragDataReceivedAsync *m)
 {
 	g_object_unref(m->context);
-	camel_object_unref(m->store);
+	g_object_unref (m->store);
 	g_free(m->full_name);
 	gtk_selection_data_free (m->selection);
 }
@@ -1682,7 +1688,14 @@ tree_drag_data_action(struct _DragDataReceivedAsync *m)
 }
 
 static void
-tree_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint y, GtkSelectionData *selection, guint info, guint time, EMFolderTree *folder_tree)
+tree_drag_data_received (GtkWidget *widget,
+                         GdkDragContext *context,
+                         gint x,
+                         gint y,
+                         GtkSelectionData *selection,
+                         guint info,
+                         guint time,
+                         EMFolderTree *folder_tree)
 {
 	GtkTreeViewDropPosition pos;
 	GtkTreeModel *model;
@@ -1701,7 +1714,12 @@ tree_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint
 		return;
 
 	/* this means we are receiving no data */
-	if (!selection->data || selection->length == -1) {
+	if (gtk_selection_data_get_data (selection) == NULL) {
+		gtk_drag_finish(context, FALSE, FALSE, GDK_CURRENT_TIME);
+		return;
+	}
+
+	if (gtk_selection_data_get_length (selection) == -1) {
 		gtk_drag_finish(context, FALSE, FALSE, GDK_CURRENT_TIME);
 		return;
 	}
@@ -1727,9 +1745,9 @@ tree_drag_data_received(GtkWidget *widget, GdkDragContext *context, gint x, gint
 	m->context = context;
 	g_object_ref(context);
 	m->store = store;
-	camel_object_ref(store);
+	g_object_ref (store);
 	m->full_name = full_name;
-	m->action = context->action;
+	m->action = gdk_drag_context_get_selected_action (context);
 	m->info = info;
 
 	/* need to copy, goes away once we exit */
@@ -1761,16 +1779,16 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 	GList *targets;
 	guint32 flags = 0;
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (folder_tree));
-
 	/* This is a bit of a mess, but should handle all the cases properly */
 
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (folder_tree));
+
 	if (!gtk_tree_model_get_iter (model, &iter, path))
 		return GDK_NONE;
 
 	/* We may override these further down. */
-	*actions = context->actions;
-	*suggested_action = context->suggested_action;
+	*actions = gdk_drag_context_get_actions (context);
+	*suggested_action = gdk_drag_context_get_suggested_action (context);
 
 	gtk_tree_model_get (
 		model, &iter,
@@ -1782,29 +1800,10 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 
 	local = e_mail_local_get_store ();
 
-	targets = context->targets;
+	targets = gdk_drag_context_list_targets (context);
 
 	/* Check for special destinations */
 	if (uri && full_name) {
-#if 0
-		/* only allow copying/moving folders (not messages) into the local Outbox */
-		if (dstore == local && !strcmp (full_name, "Outbox")) {
-			GdkAtom xfolder;
-
-			xfolder = drop_atoms[DND_DROP_TYPE_FOLDER];
-			while (targets != NULL) {
-				if (targets->data == (gpointer) xfolder) {
-					atom = xfolder;
-					goto done;
-				}
-
-				targets = targets->next;
-			}
-
-			goto done;
-		}
-#endif
-
 		/* don't allow copying/moving into the UNMATCHED vfolder */
 		if (!strncmp (uri, "vfolder:", 8) && !strcmp (full_name, CAMEL_UNMATCHED_NAME))
 			goto done;
@@ -1916,8 +1915,8 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 
 		/* Search Folders can only be dropped into other Search Folders */
 		if (strncmp(src_uri, "vfolder:", 8) == 0) {
-			/* TODO: not sure if this is legal, but it works, force move only for vfolders */
-			context->suggested_action = GDK_ACTION_MOVE;
+			/* force move only for vfolders */
+			*suggested_action = GDK_ACTION_MOVE;
 
 			if (uri && strncmp(uri, "vfolder:", 8) == 0) {
 				GdkAtom xfolder;
@@ -1979,7 +1978,12 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 }
 
 static gboolean
-tree_drag_drop (GtkWidget *widget, GdkDragContext *context, gint x, gint y, guint time, EMFolderTree *folder_tree)
+tree_drag_drop (GtkWidget *widget,
+                GdkDragContext *context,
+                gint x,
+                gint y,
+                guint time,
+                EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	GtkTreeViewColumn *column;
@@ -2018,7 +2022,9 @@ tree_drag_drop (GtkWidget *widget, GdkDragContext *context, gint x, gint y, guin
 }
 
 static void
-tree_drag_end (GtkWidget *widget, GdkDragContext *context, EMFolderTree *folder_tree)
+tree_drag_end (GtkWidget *widget,
+               GdkDragContext *context,
+               EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 
@@ -2031,7 +2037,10 @@ tree_drag_end (GtkWidget *widget, GdkDragContext *context, EMFolderTree *folder_
 }
 
 static void
-tree_drag_leave (GtkWidget *widget, GdkDragContext *context, guint time, EMFolderTree *folder_tree)
+tree_drag_leave (GtkWidget *widget,
+                 GdkDragContext *context,
+                 guint time,
+                 EMFolderTree *folder_tree)
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	GtkTreeView *tree_view;
@@ -2060,12 +2069,14 @@ tree_drag_leave (GtkWidget *widget, GdkDragContext *context, guint time, EMFolde
 static gboolean
 tree_autoscroll (EMFolderTree *folder_tree)
 {
-	GtkAdjustment *vadjustment;
+	GtkAdjustment *adjustment;
 	GtkTreeView *tree_view;
 	GdkRectangle rect;
 	GdkWindow *window;
 	gint offset, y;
-	gfloat value;
+	gdouble page_size;
+	gdouble upper;
+	gdouble value;
 
 	/* get the y pointer position relative to the treeview */
 	tree_view = GTK_TREE_VIEW (folder_tree);
@@ -2085,10 +2096,14 @@ tree_autoscroll (EMFolderTree *folder_tree)
 			return TRUE;
 	}
 
-	vadjustment = gtk_tree_view_get_vadjustment (tree_view);
+	adjustment = gtk_tree_view_get_vadjustment (tree_view);
 
-	value = CLAMP (vadjustment->value + offset, 0.0, vadjustment->upper - vadjustment->page_size);
-	gtk_adjustment_set_value (vadjustment, value);
+	page_size = gtk_adjustment_get_value (adjustment);
+	upper = gtk_adjustment_get_value (adjustment);
+	value = gtk_adjustment_get_value (adjustment);
+
+	value = CLAMP (value + offset, 0.0, upper - page_size);
+	gtk_adjustment_set_value (adjustment, value);
 
 	return TRUE;
 }
@@ -2324,11 +2339,9 @@ em_folder_tree_set_selected_list (EMFolderTree *folder_tree, GList *list, gboole
 	for (;list;list = list->next) {
 		struct _selected_uri *u = g_malloc0(sizeof(*u));
 		CamelURL *url;
-		CamelException ex = { 0 };
 
 		u->uri = g_strdup(list->data);
-		u->store = (CamelStore *)camel_session_get_service (session, u->uri, CAMEL_PROVIDER_STORE, &ex);
-		camel_exception_clear(&ex);
+		u->store = (CamelStore *)camel_session_get_service (session, u->uri, CAMEL_PROVIDER_STORE, NULL);
 
 		url = camel_url_new(u->uri, NULL);
 		if (u->store == NULL || url == NULL) {
@@ -2680,14 +2693,11 @@ em_folder_tree_get_selected_folder (EMFolderTree *folder_tree)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gchar *full_name = NULL;
-	CamelException ex;
 	CamelStore *store = NULL;
 	CamelFolder *folder = NULL;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
-	camel_exception_init (&ex);
-
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	selection = gtk_tree_view_get_selection (tree_view);
 
@@ -2696,9 +2706,8 @@ em_folder_tree_get_selected_folder (EMFolderTree *folder_tree)
 				    COL_STRING_FULL_NAME, &full_name, -1);
 
 	if (store && full_name)
-		folder = camel_store_get_folder (store, full_name, CAMEL_STORE_FOLDER_INFO_FAST, &ex);
-
-	camel_exception_clear (&ex);
+		folder = camel_store_get_folder (
+			store, full_name, CAMEL_STORE_FOLDER_INFO_FAST, NULL);
 
 	return folder;
 }
@@ -2711,14 +2720,11 @@ em_folder_tree_get_selected_folder_info (EMFolderTree *folder_tree)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gchar *full_name = NULL, *name = NULL, *uri = NULL;
-	CamelException ex;
 	CamelStore *store = NULL;
 	CamelFolderInfo *fi = NULL;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
-	camel_exception_init (&ex);
-
 	tree_view = GTK_TREE_VIEW (folder_tree);
 	selection = gtk_tree_view_get_selection (tree_view);
 
