@@ -24,18 +24,17 @@
 #define MAIL_TOOLS_H
 
 #include <glib.h>
-#include <camel/camel-folder.h>
-#include <camel/camel-mime-message.h>
+#include <camel/camel.h>
 
 /* Get the "inbox" for a url (uses global session) */
-CamelFolder *mail_tool_get_inbox (const gchar *url, CamelException *ex);
+CamelFolder *mail_tool_get_inbox (const gchar *url, GError **error);
 
 /* Get the "trash" for a url (uses global session) */
-CamelFolder *mail_tool_get_trash (const gchar *url, gint connect, CamelException *ex);
+CamelFolder *mail_tool_get_trash (const gchar *url, gint connect, GError **error);
 
 /* Does a camel_movemail into the local movemail folder
  * and returns the path to the new movemail folder that was created. which shoudl be freed later */
-gchar *mail_tool_do_movemail (const gchar *source_url, CamelException *ex);
+gchar *mail_tool_do_movemail (const gchar *source_url, GError **error);
 
 struct _camel_header_raw *mail_tool_remove_xevolution_headers (CamelMimeMessage *message);
 void mail_tool_restore_xevolution_headers (CamelMimeMessage *message, struct _camel_header_raw *);
@@ -47,7 +46,7 @@ gchar *mail_tool_generate_forward_subject (CamelMimeMessage *msg);
 CamelMimePart *mail_tool_make_message_attachment (CamelMimeMessage *message);
 
 /* Parse the ui into a real CamelFolder any way we know how. */
-CamelFolder *mail_tool_uri_to_folder (const gchar *uri, guint32 flags, CamelException *ex);
+CamelFolder *mail_tool_uri_to_folder (const gchar *uri, guint32 flags, GError **error);
 
 GHashTable *mail_lookup_url_table (CamelMimeMessage *mime_message);
 
