@@ -171,7 +171,7 @@ memo_shell_sidebar_backend_error_cb (EMemoShellSidebar *memo_shell_sidebar,
 
 static void
 memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
-                                     ECalendarStatus status,
+                                     const GError *error,
                                      ECal *client)
 {
 	EShellView *shell_view;
@@ -183,12 +183,14 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
-	if (status == E_CALENDAR_STATUS_AUTHENTICATION_FAILED ||
-		status == E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED)
+	if (g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
+	    g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED))
 		e_auth_cal_forget_password (client);
 
 	/* Handle errors. */
-	switch (status) {
+	switch (error ? error->code : E_CALENDAR_STATUS_OK) {
 		case E_CALENDAR_STATUS_OK:
 			break;
 
@@ -213,7 +215,7 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 			return;
 	}
 
-	g_assert (status == E_CALENDAR_STATUS_OK);
+	g_assert (error == NULL);
 
 	g_signal_handlers_disconnect_matched (
 		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
@@ -227,7 +229,7 @@ memo_shell_sidebar_client_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 
 static void
 memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
-                                      ECalendarStatus status,
+                                      const GError *error,
                                       ECal *client)
 {
 	EShellView *shell_view;
@@ -236,12 +238,14 @@ memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 
-	if (status == E_CALENDAR_STATUS_AUTHENTICATION_FAILED ||
-		status == E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED)
+	if (g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
+	    g_error_matches (error, E_CALENDAR_ERROR,
+		E_CALENDAR_STATUS_AUTHENTICATION_REQUIRED))
 		e_auth_cal_forget_password (client);
 
 	/* Handle errors. */
-	switch (status) {
+	switch (error ? error->code : E_CALENDAR_STATUS_OK) {
 		case E_CALENDAR_STATUS_OK:
 			break;
 
@@ -259,7 +263,7 @@ memo_shell_sidebar_default_opened_cb (EMemoShellSidebar *memo_shell_sidebar,
 			return;
 	}
 
-	g_assert (status == E_CALENDAR_STATUS_OK);
+	g_assert (error == NULL);
 
 	g_signal_handlers_disconnect_matched (
 		client, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
@@ -272,9 +276,15 @@ static void
 memo_shell_sidebar_set_default (EMemoShellSidebar *memo_shell_sidebar,
                                 ESource *source)
 {
+	EShellView *shell_view;
+	EShellContent *shell_content;
+	EShellSidebar *shell_sidebar;
+	EMemoShellContent *memo_shell_content;
 	ECalSourceType source_type;
 	GHashTable *client_table;
+	ECalModel *model;
 	ECal *client;
+	icaltimezone *timezone;
 	const gchar *uid;
 
 	source_type = E_CAL_SOURCE_TYPE_JOURNAL;
@@ -295,11 +305,21 @@ memo_shell_sidebar_set_default (EMemoShellSidebar *memo_shell_sidebar,
 	g_return_if_fail (client != NULL);
 
 	g_signal_connect_swapped (
-		client, "cal-opened",
+		client, "cal-opened-ex",
 		G_CALLBACK (memo_shell_sidebar_default_opened_cb),
 		memo_shell_sidebar);
 
-	e_cal_set_default_timezone (client, e_cal_model_get_timezone (e_memo_shell_content_get_memo_model (E_MEMO_SHELL_CONTENT (e_shell_view_get_shell_content (e_shell_sidebar_get_shell_view (E_SHELL_SIDEBAR (memo_shell_sidebar)))))), NULL);
+	/* FIXME Sidebar should not be accessing the EShellContent.
+	 *       This probably needs to be moved to EMemoShellView. */
+	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
+
+	memo_shell_content = E_MEMO_SHELL_CONTENT (shell_content);
+	model = e_memo_shell_content_get_memo_model (memo_shell_content);
+	timezone = e_cal_model_get_timezone (model);
+
+	e_cal_set_default_timezone (client, timezone, NULL);
 	e_cal_open_async (client, FALSE);
 }
 
@@ -676,8 +696,8 @@ memo_shell_sidebar_class_init (EMemoShellSidebarClass *class)
 		PROP_DEFAULT_CLIENT,
 		g_param_spec_object (
 			"default-client",
-			_("Default Memo Client"),
-			_("Default client for memo operations"),
+			"Default Memo Client",
+			"Default client for memo operations",
 			E_TYPE_CAL,
 			G_PARAM_READABLE));
 
@@ -686,8 +706,8 @@ memo_shell_sidebar_class_init (EMemoShellSidebarClass *class)
 		PROP_SELECTOR,
 		g_param_spec_object (
 			"selector",
-			_("Source Selector Widget"),
-			_("This widget displays groups of memo lists"),
+			"Source Selector Widget",
+			"This widget displays groups of memo lists",
 			E_TYPE_SOURCE_SELECTOR,
 			G_PARAM_READABLE));
 
@@ -813,11 +833,17 @@ void
 e_memo_shell_sidebar_add_source (EMemoShellSidebar *memo_shell_sidebar,
                                  ESource *source)
 {
+	EShellView *shell_view;
+	EShellContent *shell_content;
+	EShellSidebar *shell_sidebar;
+	EMemoShellContent *memo_shell_content;
 	ECalSourceType source_type;
 	ESourceSelector *selector;
 	GHashTable *client_table;
+	ECalModel *model;
 	ECal *default_client;
 	ECal *client;
+	icaltimezone *timezone;
 	const gchar *uid;
 	const gchar *uri;
 	gchar *message;
@@ -872,11 +898,21 @@ e_memo_shell_sidebar_add_source (EMemoShellSidebar *memo_shell_sidebar,
 	g_free (message);
 
 	g_signal_connect_swapped (
-		client, "cal-opened",
+		client, "cal-opened-ex",
 		G_CALLBACK (memo_shell_sidebar_client_opened_cb),
 		memo_shell_sidebar);
 
-	e_cal_set_default_timezone (client, e_cal_model_get_timezone (e_memo_shell_content_get_memo_model (E_MEMO_SHELL_CONTENT (e_shell_view_get_shell_content (e_shell_sidebar_get_shell_view (E_SHELL_SIDEBAR (memo_shell_sidebar)))))), NULL);
+	/* FIXME Sidebar should not be accessing the EShellContent.
+	 *       This probably needs to be moved to EMemoShellView. */
+	shell_sidebar = E_SHELL_SIDEBAR (memo_shell_sidebar);
+	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
+
+	memo_shell_content = E_MEMO_SHELL_CONTENT (shell_content);
+	model = e_memo_shell_content_get_memo_model (memo_shell_content);
+	timezone = e_cal_model_get_timezone (model);
+
+	e_cal_set_default_timezone (client, timezone, NULL);
 	e_cal_open_async (client, FALSE);
 }
 
