@@ -264,6 +264,31 @@ task_shell_content_model_row_changed_cb (ETaskShellContent *task_shell_content,
 		task_shell_content, 0, E_TABLE (task_table));
 }
 
+static void
+task_shell_content_restore_state_cb (EShellWindow *shell_window,
+                                     EShellView *shell_view,
+                                     EShellContent *shell_content)
+{
+	ETaskShellContentPrivate *priv;
+	GConfBridge *bridge;
+	GObject *object;
+	const gchar *key;
+
+	priv = E_TASK_SHELL_CONTENT_GET_PRIVATE (shell_content);
+
+	/* Bind GObject properties to GConf keys. */
+
+	bridge = gconf_bridge_get ();
+
+	object = G_OBJECT (priv->paned);
+	key = "/apps/evolution/calendar/display/task_hpane_position";
+	gconf_bridge_bind_property_delayed (bridge, key, object, "hposition");
+
+	object = G_OBJECT (priv->paned);
+	key = "/apps/evolution/calendar/display/task_vpane_position";
+	gconf_bridge_bind_property_delayed (bridge, key, object, "vposition");
+}
+
 static GtkOrientation
 task_shell_content_get_orientation (ETaskShellContent *task_shell_content)
 {
@@ -395,12 +420,10 @@ task_shell_content_constructed (GObject *object)
 	EShellView *shell_view;
 	GalViewInstance *view_instance;
 	icaltimezone *timezone;
-	GConfBridge *bridge;
 	GtkTargetList *target_list;
 	GtkTargetEntry *targets;
 	GtkWidget *container;
 	GtkWidget *widget;
-	const gchar *key;
 	gint n_targets;
 
 	priv = E_TASK_SHELL_CONTENT_GET_PRIVATE (object);
@@ -415,7 +438,7 @@ task_shell_content_constructed (GObject *object)
 	shell = e_shell_window_get_shell (shell_window);
 	shell_settings = e_shell_get_shell_settings (shell);
 
-	priv->task_model = e_cal_model_tasks_new (shell_settings);
+	priv->task_model = e_cal_model_tasks_new ();
 
 	timezone = e_shell_settings_get_pointer (
 		shell_settings, "cal-timezone");
@@ -521,17 +544,12 @@ task_shell_content_constructed (GObject *object)
 	gal_view_instance_load (view_instance);
 	priv->view_instance = view_instance;
 
-	/* Bind GObject properties to GConf keys. */
-
-	bridge = gconf_bridge_get ();
-
-	object = G_OBJECT (priv->paned);
-	key = "/apps/evolution/calendar/display/task_hpane_position";
-	gconf_bridge_bind_property_delayed (bridge, key, object, "hposition");
-
-	object = G_OBJECT (priv->paned);
-	key = "/apps/evolution/calendar/display/task_vpane_position";
-	gconf_bridge_bind_property_delayed (bridge, key, object, "vposition");
+	/* Restore pane positions from the last session once
+	 * the shell view is fully initialized and visible. */
+	g_signal_connect (
+		shell_window, "shell-view-created::tasks",
+		G_CALLBACK (task_shell_content_restore_state_cb),
+		shell_content);
 }
 
 static guint32
@@ -602,6 +620,16 @@ task_shell_content_check_state (EShellContent *shell_content)
 	return state;
 }
 
+static void
+task_shell_content_focus_search_results (EShellContent *shell_content)
+{
+	ETaskShellContentPrivate *priv;
+
+	priv = E_TASK_SHELL_CONTENT_GET_PRIVATE (shell_content);
+
+	gtk_widget_grab_focus (priv->task_table);
+}
+
 static void
 task_shell_content_class_init (ETaskShellContentClass *class)
 {
@@ -620,14 +648,15 @@ task_shell_content_class_init (ETaskShellContentClass *class)
 
 	shell_content_class = E_SHELL_CONTENT_CLASS (class);
 	shell_content_class->check_state = task_shell_content_check_state;
+	shell_content_class->focus_search_results = task_shell_content_focus_search_results;
 
 	g_object_class_install_property (
 		object_class,
 		PROP_MODEL,
 		g_param_spec_object (
 			"model",
-			_("Model"),
-			_("The task table model"),
+			"Model",
+			"The task table model",
 			E_TYPE_CAL_MODEL,
 			G_PARAM_READABLE));
 
@@ -636,8 +665,8 @@ task_shell_content_class_init (ETaskShellContentClass *class)
 		PROP_PREVIEW_VISIBLE,
 		g_param_spec_boolean (
 			"preview-visible",
-			_("Preview is Visible"),
-			_("Whether the preview pane is visible"),
+			"Preview is Visible",
+			"Whether the preview pane is visible",
 			TRUE,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT));
@@ -752,6 +781,7 @@ e_task_shell_content_set_preview_visible (ETaskShellContent *task_shell_content,
 EShellSearchbar *
 e_task_shell_content_get_searchbar (ETaskShellContent *task_shell_content)
 {
+	EShellView *shell_view;
 	EShellContent *shell_content;
 	GtkWidget *widget;
 
@@ -759,7 +789,8 @@ e_task_shell_content_get_searchbar (ETaskShellContent *task_shell_content)
 		E_IS_TASK_SHELL_CONTENT (task_shell_content), NULL);
 
 	shell_content = E_SHELL_CONTENT (task_shell_content);
-	widget = e_shell_content_get_searchbar (shell_content);
+	shell_view = e_shell_content_get_shell_view (shell_content);
+	widget = e_shell_view_get_searchbar (shell_view);
 
 	return E_SHELL_SEARCHBAR (widget);
 }
