@@ -62,12 +62,12 @@ search_results_exec (SearchResultsMsg *msg)
 	camel_operation_register (msg->cancel);
 
 	copied_list = g_list_copy (msg->folder_list);
-	g_list_foreach (copied_list, (GFunc) camel_object_ref, NULL);
+	g_list_foreach (copied_list, (GFunc) g_object_ref, NULL);
 
 	camel_vee_folder_set_folders (
 		CAMEL_VEE_FOLDER (msg->folder), copied_list);
 
-	g_list_foreach (copied_list, (GFunc) camel_object_unref, NULL);
+	g_list_foreach (copied_list, (GFunc) g_object_unref, NULL);
 	g_list_free (copied_list);
 }
 
@@ -79,9 +79,9 @@ search_results_done (SearchResultsMsg *msg)
 static void
 search_results_free (SearchResultsMsg *msg)
 {
-	camel_object_unref (msg->folder);
+	g_object_unref (msg->folder);
 
-	g_list_foreach (msg->folder_list, (GFunc) camel_object_unref, NULL);
+	g_list_foreach (msg->folder_list, (GFunc) g_object_unref, NULL);
 	g_list_free (msg->folder_list);
 }
 
@@ -101,7 +101,7 @@ mail_shell_view_setup_search_results_folder (CamelFolder *folder,
 	SearchResultsMsg *msg;
 	gint id;
 
-	camel_object_ref (folder);
+	g_object_ref (folder);
 
 	msg = mail_msg_new (&search_results_setup_info);
 	msg->folder = folder;
@@ -487,7 +487,7 @@ all_accounts:
 	text = e_shell_searchbar_get_search_text (searchbar);
 	if (text == NULL || *text == '\0') {
 		if (priv->search_account_all != NULL) {
-			camel_object_unref (priv->search_account_all);
+			g_object_unref (priv->search_account_all);
 			priv->search_account_all = NULL;
 		}
 
@@ -551,38 +551,28 @@ all_accounts:
 	/* Add local folders. */
 	iter = mail_vfolder_get_sources_local ();
 	while (iter != NULL) {
-		CamelException ex;
-
-		camel_exception_init (&ex);
-
 		folder_uri = iter->data;
-		folder = mail_tool_uri_to_folder (folder_uri, 0, &ex);
+		folder = mail_tool_uri_to_folder (folder_uri, 0, NULL);
 
 		if (folder != NULL)
 			list = g_list_append (list, folder);
 		else
 			g_warning ("Could not open vfolder source: %s", folder_uri);
 
-		camel_exception_clear (&ex);
 		iter = g_list_next (iter);
 	}
 
 	/* Add remote folders. */
 	iter = mail_vfolder_get_sources_remote ();
 	while (iter != NULL) {
-		CamelException ex;
-
-		camel_exception_init (&ex);
-
 		folder_uri = iter->data;
-		folder = mail_tool_uri_to_folder (folder_uri, 0, &ex);
+		folder = mail_tool_uri_to_folder (folder_uri, 0, NULL);
 
 		if (folder != NULL)
 			list = g_list_append (list, folder);
 		else
 			g_warning ("Could not open vfolder source: %s", folder_uri);
 
-		camel_exception_clear (&ex);
 		iter = g_list_next (iter);
 	}
 
@@ -614,7 +604,7 @@ current_account:
 	text = e_shell_searchbar_get_search_text (searchbar);
 	if (text == NULL || *text == '\0') {
 		if (priv->search_account_current != NULL) {
-			camel_object_unref (priv->search_account_current);
+			g_object_unref (priv->search_account_current);
 			priv->search_account_current = NULL;
 		}
 
@@ -664,7 +654,7 @@ current_account:
 
 	/* Create a new search folder. */
 
-	store = folder->parent_store;
+	store = camel_folder_get_parent_store (folder);
 	list = NULL;  /* list of CamelFolders */
 
 	if (store->folders != NULL) {
@@ -795,6 +785,7 @@ mail_shell_view_update_actions (EShellView *shell_view)
 	gboolean folder_is_trash;
 	gboolean folder_has_unread_rec = FALSE;
 	gboolean folder_tree_and_message_list_agree = TRUE;
+	gboolean have_enabled_account;
 
 	/* Chain up to parent's update_actions() method. */
 	E_SHELL_VIEW_CLASS (parent_class)->update_actions (shell_view);
@@ -805,7 +796,11 @@ mail_shell_view_update_actions (EShellView *shell_view)
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
 	reader = E_MAIL_READER (mail_shell_content);
-	e_mail_reader_update_actions (reader);
+	state = e_mail_reader_check_state (reader);
+	e_mail_reader_update_actions (reader, state);
+
+	have_enabled_account =
+		(state & E_MAIL_READER_HAVE_ENABLED_ACCOUNT);
 
 	mail_shell_sidebar = mail_shell_view->priv->mail_shell_sidebar;
 	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
@@ -867,6 +862,7 @@ mail_shell_view_update_actions (EShellView *shell_view)
 		g_free (uri);
 	}
 
+
 	action = ACTION (MAIL_ACCOUNT_DISABLE);
 	sensitive = (account != NULL) && folder_is_store;
 	if (account_is_groupwise)
@@ -930,6 +926,10 @@ mail_shell_view_update_actions (EShellView *shell_view)
 	sensitive = folder_has_unread_rec && !folder_is_store;
 	gtk_action_set_sensitive (action, sensitive);
 
+	action = ACTION (MAIL_TOOLS_SUBSCRIPTIONS);
+	sensitive = have_enabled_account;
+	gtk_action_set_sensitive (action, sensitive);
+
 	e_mail_shell_view_update_popup_labels (mail_shell_view);
 }
 
