@@ -254,13 +254,10 @@ shell_content_forall (GtkContainer *container,
                       gpointer callback_data)
 {
 	EShellContentPrivate *priv;
-	GtkWidget *parent;
 
 	priv = E_SHELL_CONTENT_GET_PRIVATE (container);
-	parent = gtk_widget_get_parent (priv->searchbar);
 
-	if (include_internals && priv->searchbar != NULL &&
-		container == GTK_CONTAINER (parent))
+	if (priv->searchbar != NULL)
 		callback (priv->searchbar, callback_data);
 
 	/* Chain up to parent's forall() method. */
@@ -346,10 +343,8 @@ e_shell_content_set_searchbar (EShellContent *shell_content,
 {
 	g_return_if_fail (E_IS_SHELL_CONTENT (shell_content));
 
-	if (searchbar != NULL) {
+	if (searchbar != NULL)
 		g_return_if_fail (GTK_IS_WIDGET (searchbar));
-		g_object_ref_sink (searchbar);
-	}
 
 	if (shell_content->priv->searchbar != NULL)
 		gtk_container_remove (
@@ -390,6 +385,29 @@ e_shell_content_check_state (EShellContent *shell_content)
 	return shell_content_class->check_state (shell_content);
 }
 
+/**
+ * e_shell_content_focus_search_results:
+ * @shell_content: an #EShellContent
+ *
+ * #EShellContent subclasses should implement the
+ * <structfield>focus_search_results</structfield> method in
+ * #EShellContentClass to direct input focus to the widget
+ * displaying search results.  This is usually called during
+ * e_shell_view_execute_search().
+ **/
+void
+e_shell_content_focus_search_results (EShellContent *shell_content)
+{
+	EShellContentClass *shell_content_class;
+
+	g_return_if_fail (E_IS_SHELL_CONTENT (shell_content));
+
+	shell_content_class = E_SHELL_CONTENT_GET_CLASS (shell_content);
+
+	if (shell_content_class->focus_search_results != NULL)
+		shell_content_class->focus_search_results (shell_content);
+}
+
 /**
  * e_shell_content_get_shell_view:
  * @shell_content: an #EShellContent
