@@ -108,7 +108,6 @@ gvisad_setup_validate_button (GalViewInstanceSaveAsDialog *dialog)
 	}
 }
 
-
 static void
 gvisad_setup_radio_buttons (GalViewInstanceSaveAsDialog *dialog)
 {
@@ -155,7 +154,6 @@ gvisad_entry_changed (GtkWidget *widget, GalViewInstanceSaveAsDialog *dialog)
 	gvisad_setup_validate_button (dialog);
 }
 
-
 /* Method override implementations */
 static void
 gal_view_instance_save_as_dialog_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
@@ -200,9 +198,9 @@ gal_view_instance_save_as_dialog_dispose (GObject *object)
 {
 	GalViewInstanceSaveAsDialog *gal_view_instance_save_as_dialog = GAL_VIEW_INSTANCE_SAVE_AS_DIALOG (object);
 
-	if (gal_view_instance_save_as_dialog->gui)
-		g_object_unref (gal_view_instance_save_as_dialog->gui);
-	gal_view_instance_save_as_dialog->gui = NULL;
+	if (gal_view_instance_save_as_dialog->builder)
+		g_object_unref (gal_view_instance_save_as_dialog->builder);
+	gal_view_instance_save_as_dialog->builder = NULL;
 
 	if (G_OBJECT_CLASS (gal_view_instance_save_as_dialog_parent_class)->dispose)
 		(* G_OBJECT_CLASS (gal_view_instance_save_as_dialog_parent_class)->dispose) (object);
@@ -222,8 +220,8 @@ gal_view_instance_save_as_dialog_class_init (GalViewInstanceSaveAsDialogClass *k
 
 	g_object_class_install_property (object_class, PROP_INSTANCE,
 					 g_param_spec_object ("instance",
-							      _("Instance"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Instance",
+							      NULL,
 							      GAL_VIEW_INSTANCE_TYPE,
 							      G_PARAM_READWRITE));
 }
@@ -231,44 +229,37 @@ gal_view_instance_save_as_dialog_class_init (GalViewInstanceSaveAsDialogClass *k
 static void
 gal_view_instance_save_as_dialog_init (GalViewInstanceSaveAsDialog *dialog)
 {
-	GladeXML *gui;
+	GtkWidget *content_area;
 	GtkWidget *widget;
 
-	gchar *filename = g_build_filename (EVOLUTION_GLADEDIR,
-					    "gal-view-instance-save-as-dialog.glade",
-					    NULL);
-
 	dialog->instance = NULL;
 	dialog->model = NULL;
 	dialog->collection = NULL;
 
-	gui = glade_xml_new_with_domain (filename , NULL, GETTEXT_PACKAGE);
-	g_free (filename);
-	dialog->gui = gui;
+	dialog->builder = gtk_builder_new ();
+	e_load_ui_builder_definition (
+		dialog->builder, "gal-view-instance-save-as-dialog.ui");
 
-	widget = glade_xml_get_widget (gui, "vbox-top");
-	if (!widget) {
-		return;
-	}
-
-	g_object_ref (widget);
-	gtk_container_remove (GTK_CONTAINER (widget->parent), widget);
+	widget = e_builder_get_widget (dialog->builder, "vbox-top");
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	gtk_box_pack_start (GTK_BOX (content_area), widget, TRUE, TRUE, 0);
 
 	/* TODO: add position/size saving/restoring */
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 360);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
-	g_object_unref (widget);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
-	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_OK, GTK_RESPONSE_OK,
-				NULL);
+	gtk_dialog_add_buttons (
+		GTK_DIALOG (dialog),
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+		NULL);
 
-	dialog->scrolledwindow = glade_xml_get_widget (dialog->gui, "scrolledwindow2");
-	dialog->treeview = GTK_TREE_VIEW (glade_xml_get_widget (dialog->gui, "custom-replace"));
-	dialog->entry_create = glade_xml_get_widget (dialog->gui, "entry-create");
-	dialog->radiobutton_replace = glade_xml_get_widget (dialog->gui, "radiobutton-replace");
-	dialog->radiobutton_create = glade_xml_get_widget (dialog->gui, "radiobutton-create");
+	dialog->scrolledwindow = e_builder_get_widget (dialog->builder, "scrolledwindow2");
+	dialog->treeview = GTK_TREE_VIEW (e_builder_get_widget (dialog->builder, "custom-replace"));
+	dialog->entry_create = e_builder_get_widget (dialog->builder, "entry-create");
+	dialog->radiobutton_replace = e_builder_get_widget (dialog->builder, "radiobutton-replace");
+	dialog->radiobutton_create = e_builder_get_widget (dialog->builder, "radiobutton-create");
 
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (dialog->treeview), FALSE);
 	gtk_tree_view_set_headers_visible (dialog->treeview, FALSE);
@@ -295,7 +286,7 @@ gal_view_instance_save_as_dialog_init (GalViewInstanceSaveAsDialog *dialog)
 GtkWidget *
 gal_view_instance_save_as_dialog_new (GalViewInstance *instance)
 {
-	GtkWidget *widget = g_object_new (GAL_VIEW_INSTANCE_SAVE_AS_DIALOG_TYPE, NULL);
+	GtkWidget *widget = g_object_new (GAL_TYPE_VIEW_INSTANCE_SAVE_AS_DIALOG, NULL);
 	gal_view_instance_save_as_dialog_set_instance (GAL_VIEW_INSTANCE_SAVE_AS_DIALOG (widget), instance);
 	return widget;
 }
