@@ -58,7 +58,9 @@
 #define d(x)
 
 #if d(!)0
-#define e_table_item_leave_edit_(x) (e_table_item_leave_edit((x)), g_print ("%s: e_table_item_leave_edit\n", __FUNCTION__))
+#define e_table_item_leave_edit_(x) \
+	(e_table_item_leave_edit ((x)), \
+	 g_print ("%s: e_table_item_leave_edit\n", __FUNCTION__))
 #else
 #define e_table_item_leave_edit_(x) (e_table_item_leave_edit((x)))
 #endif
@@ -199,7 +201,9 @@ e_table_state_change (ETable *et)
 	g_signal_emit (G_OBJECT (et), et_signals [STATE_CHANGE], 0);
 }
 
-#define CHECK_HORIZONTAL(et) if ((et)->horizontal_scrolling || (et)->horizontal_resize) e_table_header_update_horizontal (et->header);
+#define CHECK_HORIZONTAL(et) \
+	if ((et)->horizontal_scrolling || (et)->horizontal_resize) \
+		e_table_header_update_horizontal (et->header);
 
 static void
 clear_current_search_col (ETable *et)
@@ -288,7 +292,8 @@ connect_header (ETable *e_table, ETableState *state)
 	if (e_table->header != NULL)
 		disconnect_header (e_table);
 
-	e_table->header = e_table_state_to_header (GTK_WIDGET(e_table), e_table->full_header, state);
+	e_table->header = e_table_state_to_header (
+		GTK_WIDGET (e_table), e_table->full_header, state);
 
 	e_table->structure_change_id =
 		g_signal_connect (G_OBJECT (e_table->header), "structure_change",
@@ -409,7 +414,11 @@ et_unrealize (GtkWidget *widget)
 }
 
 static gboolean
-check_row (ETable *et, gint model_row, gint col, ETableSearchFunc search, gchar *string)
+check_row (ETable *et,
+           gint model_row,
+           gint col,
+           ETableSearchFunc search,
+           gchar *string)
 {
 	gconstpointer value;
 
@@ -419,7 +428,10 @@ check_row (ETable *et, gint model_row, gint col, ETableSearchFunc search, gchar
 }
 
 static gboolean
-et_search_search (ETableSearch *search, gchar *string, ETableSearchFlags flags, ETable *et)
+et_search_search (ETableSearch *search,
+                  gchar *string,
+                  ETableSearchFlags flags,
+                  ETable *et)
 {
 	gint cursor;
 	gint rows;
@@ -435,7 +447,9 @@ et_search_search (ETableSearch *search, gchar *string, ETableSearchFlags flags,
 		     "cursor_row", &cursor,
 		     NULL);
 
-	if ((flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST) && cursor < rows && cursor >= 0 && check_row (et, cursor, col->col_idx, col->search, string))
+	if ((flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST) &&
+		cursor < rows && cursor >= 0 &&
+		check_row (et, cursor, col->col_idx, col->search, string))
 		return TRUE;
 
 	cursor = e_sorter_model_to_sorted (E_SORTER (et->sorter), cursor);
@@ -443,7 +457,9 @@ et_search_search (ETableSearch *search, gchar *string, ETableSearchFlags flags,
 	for (i = cursor + 1; i < rows; i++) {
 		gint model_row = e_sorter_sorted_to_model (E_SORTER (et->sorter), i);
 		if (check_row (et, model_row, col->col_idx, col->search, string)) {
-			e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->selection), model_row, col->col_idx, GDK_CONTROL_MASK);
+			e_selection_model_select_as_key_press (
+				E_SELECTION_MODEL (et->selection),
+				model_row, col->col_idx, GDK_CONTROL_MASK);
 			return TRUE;
 		}
 	}
@@ -451,7 +467,9 @@ et_search_search (ETableSearch *search, gchar *string, ETableSearchFlags flags,
 	for (i = 0; i < cursor; i++) {
 		gint model_row = e_sorter_sorted_to_model (E_SORTER (et->sorter), i);
 		if (check_row (et, model_row, col->col_idx, col->search, string)) {
-			e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->selection), model_row, col->col_idx, GDK_CONTROL_MASK);
+			e_selection_model_select_as_key_press (
+				E_SELECTION_MODEL (et->selection),
+				model_row, col->col_idx, GDK_CONTROL_MASK);
 			return TRUE;
 		}
 	}
@@ -459,7 +477,9 @@ et_search_search (ETableSearch *search, gchar *string, ETableSearchFlags flags,
 	cursor = e_sorter_sorted_to_model (E_SORTER (et->sorter), cursor);
 
 	/* Check if the cursor row is the only matching row. */
-	return (!(flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST) && cursor < rows && cursor >= 0 && check_row (et, cursor, col->col_idx, col->search, string));
+	return (!(flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST) &&
+		cursor < rows && cursor >= 0 &&
+		check_row (et, cursor, col->col_idx, col->search, string));
 }
 
 static void
@@ -471,10 +491,10 @@ et_search_accept (ETableSearch *search, ETable *et)
 	if (col == NULL)
 		return;
 
-	g_object_get(et->selection,
-		     "cursor_row", &cursor,
-		     NULL);
-	e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->selection), cursor, col->col_idx, 0);
+	g_object_get (et->selection, "cursor_row", &cursor, NULL);
+
+	e_selection_model_select_as_key_press (
+		E_SELECTION_MODEL (et->selection), cursor, col->col_idx, 0);
 }
 
 static void
@@ -509,11 +529,9 @@ et_finalize (GObject *object)
 static void
 e_table_init (ETable *e_table)
 {
-	GtkTable *gtk_table = GTK_TABLE (e_table);
+	gtk_widget_set_can_focus (GTK_WIDGET (e_table), TRUE);
 
-	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (e_table), GTK_CAN_FOCUS);
-
-	gtk_table->homogeneous          = FALSE;
+	gtk_table_set_homogeneous (GTK_TABLE (e_table), FALSE);
 
 	e_table->sort_info              = NULL;
 	e_table->group_info_change_id   = 0;
@@ -582,7 +600,7 @@ et_focus (GtkWidget *container, GtkDirectionType direction)
 
 	e_table = E_TABLE (container);
 
-	if (GTK_CONTAINER (container)->focus_child) {
+	if (gtk_container_get_focus_child (GTK_CONTAINER (container))) {
 		gtk_container_set_focus_child (GTK_CONTAINER (container), NULL);
 		return FALSE;
 	}
@@ -615,14 +633,18 @@ set_header_canvas_width (ETable *e_table)
 static void
 header_canvas_size_allocate (GtkWidget *widget, GtkAllocation *alloc, ETable *e_table)
 {
+	GtkAllocation allocation;
+
 	set_header_canvas_width (e_table);
 
+	gtk_widget_get_allocation (
+		GTK_WIDGET (e_table->header_canvas), &allocation);
+
 	/* When the header item is created ->height == 0,
 	   as the font is only created when everything is realized.
 	   So we set the usize here as well, so that the size of the
 	   header is correct */
-	if (GTK_WIDGET (e_table->header_canvas)->allocation.height !=
-	    E_TABLE_HEADER_ITEM (e_table->header_item)->height)
+	if (allocation.height != E_TABLE_HEADER_ITEM (e_table->header_item)->height)
 		g_object_set (
 			e_table->header_canvas, "height-request",
 			E_TABLE_HEADER_ITEM (e_table->header_item)->height,
@@ -688,14 +710,16 @@ table_canvas_reflow_idle (ETable *e_table)
 {
 	gdouble height, width;
 	gdouble oldheight, oldwidth;
-	GtkAllocation *alloc = &(GTK_WIDGET (e_table->table_canvas)->allocation);
+	GtkAllocation allocation;
 
-	g_object_get (e_table->canvas_vbox,
-		      "height", &height,
-		      "width", &width,
-		      NULL);
-	height = MAX ((gint)height, alloc->height);
-	width = MAX((gint)width, alloc->width);
+	gtk_widget_get_allocation (
+		GTK_WIDGET (e_table->table_canvas), &allocation);
+
+	g_object_get (
+		e_table->canvas_vbox,
+		"height", &height, "width", &width, NULL);
+	height = MAX ((gint)height, allocation.height);
+	width = MAX((gint)width, allocation.width);
 	/* I have no idea why this needs to be -1, but it works. */
 	gnome_canvas_get_scroll_region (GNOME_CANVAS (e_table->table_canvas),
 					NULL, NULL, &oldwidth, &oldheight);
@@ -745,7 +769,9 @@ static void
 table_canvas_reflow (GnomeCanvas *canvas, ETable *e_table)
 {
 	if (!e_table->reflow_idle_id)
-		e_table->reflow_idle_id = g_idle_add_full (400, (GSourceFunc) table_canvas_reflow_idle, e_table, NULL);
+		e_table->reflow_idle_id = g_idle_add_full (
+			400, (GSourceFunc) table_canvas_reflow_idle,
+			e_table, NULL);
 }
 
 static void
@@ -787,7 +813,11 @@ static gboolean
 group_right_click (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *et)
 {
 	gboolean return_val = FALSE;
-	g_signal_emit (G_OBJECT (et), et_signals [RIGHT_CLICK], 0, row, col, event, &return_val);
+
+	g_signal_emit (
+		et, et_signals[RIGHT_CLICK], 0,
+		row, col, event, &return_val);
+
 	return return_val;
 }
 
@@ -805,14 +835,24 @@ group_key_press (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *
 	gboolean return_val = FALSE;
 	GdkEventKey *key = (GdkEventKey *) event;
 	gint y, row_local, col_local;
-	GtkAdjustment *vadj;
+	GtkAdjustment *adjustment;
+	GtkLayout *layout;
+	gdouble page_size;
+	gdouble upper;
+	gdouble value;
+
+	layout = GTK_LAYOUT (et->table_canvas);
+	adjustment = gtk_layout_get_vadjustment (layout);
 
 	switch (key->keyval) {
 	case GDK_Page_Down:
 	case GDK_KP_Page_Down:
-		vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (et->table_canvas));
-		y = CLAMP(vadj->value + (2 * vadj->page_size - 50), 0, vadj->upper);
-		y -= vadj->value;
+		page_size = gtk_adjustment_get_page_size (adjustment);
+		upper = gtk_adjustment_get_value (adjustment);
+		value = gtk_adjustment_get_value (adjustment);
+
+		y = CLAMP (value + (2 * page_size - 50), 0, upper);
+		y -= value;
 		e_table_get_cell_at (et, 30, y, &row_local, &col_local);
 
 		if (row_local == -1)
@@ -820,14 +860,19 @@ group_key_press (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *
 
 		row_local = e_table_view_to_model_row (et, row_local);
 		col_local = e_selection_model_cursor_col (E_SELECTION_MODEL (et->selection));
-		e_selection_model_select_as_key_press (E_SELECTION_MODEL (et->selection), row_local, col_local, key->state);
+		e_selection_model_select_as_key_press (
+			E_SELECTION_MODEL (et->selection),
+			row_local, col_local, key->state);
 		return_val = 1;
 		break;
 	case GDK_Page_Up:
 	case GDK_KP_Page_Up:
-		vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (et->table_canvas));
-		y = CLAMP(vadj->value - (vadj->page_size - 50), 0, vadj->upper);
-		y -= vadj->value;
+		page_size = gtk_adjustment_get_page_size (adjustment);
+		upper = gtk_adjustment_get_upper (adjustment);
+		value = gtk_adjustment_get_value (adjustment);
+
+		y = CLAMP (value - (page_size - 50), 0, upper);
+		y -= value;
 		e_table_get_cell_at (et, 30, y, &row_local, &col_local);
 
 		if (row_local == -1)
@@ -835,7 +880,9 @@ group_key_press (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *
 
 		row_local = e_table_view_to_model_row (et, row_local);
 		col_local = e_selection_model_cursor_col (E_SELECTION_MODEL (et->selection));
-		e_selection_model_select_as_key_press (E_SELECTION_MODEL (et->selection), row_local, col_local, key->state);
+		e_selection_model_select_as_key_press (
+			E_SELECTION_MODEL (et->selection),
+			row_local, col_local, key->state);
 		return_val = 1;
 		break;
 	case GDK_BackSpace:
@@ -845,7 +892,9 @@ group_key_press (ETableGroup *etg, gint row, gint col, GdkEvent *event, ETable *
 		/* Fall through */
 	default:
 		init_search (et);
-		if ((key->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK | GDK_MOD1_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK)) == 0
+		if ((key->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK |
+			GDK_MOD1_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK |
+			GDK_MOD4_MASK | GDK_MOD5_MASK)) == 0
 		    && ((key->keyval >= GDK_a && key->keyval <= GDK_z) ||
 			(key->keyval >= GDK_A && key->keyval <= GDK_Z) ||
 			(key->keyval >= GDK_0 && key->keyval <= GDK_9)))
@@ -937,20 +986,25 @@ et_build_groups (ETable *et)
 				       0);
 
 	if (et->use_click_to_add_end)
-		e_canvas_vbox_add_item_start(E_CANVAS_VBOX(et->canvas_vbox), GNOME_CANVAS_ITEM(et->group));
+		e_canvas_vbox_add_item_start (
+			E_CANVAS_VBOX (et->canvas_vbox),
+			GNOME_CANVAS_ITEM (et->group));
 	else
-		e_canvas_vbox_add_item(E_CANVAS_VBOX(et->canvas_vbox), GNOME_CANVAS_ITEM(et->group));
+		e_canvas_vbox_add_item (
+			E_CANVAS_VBOX (et->canvas_vbox),
+			GNOME_CANVAS_ITEM (et->group));
 
-	gnome_canvas_item_set(GNOME_CANVAS_ITEM(et->group),
-			      "alternating_row_colors", et->alternating_row_colors,
-			      "horizontal_draw_grid", et->horizontal_draw_grid,
-			      "vertical_draw_grid", et->vertical_draw_grid,
-			      "drawfocus", et->draw_focus,
-			      "cursor_mode", et->cursor_mode,
-			      "length_threshold", et->length_threshold,
-			      "uniform_row_height", et->uniform_row_height,
-			      "selection_model", et->selection,
-			      NULL);
+	gnome_canvas_item_set (
+		GNOME_CANVAS_ITEM(et->group),
+		"alternating_row_colors", et->alternating_row_colors,
+		"horizontal_draw_grid", et->horizontal_draw_grid,
+		"vertical_draw_grid", et->vertical_draw_grid,
+		"drawfocus", et->draw_focus,
+		"cursor_mode", et->cursor_mode,
+		"length_threshold", et->length_threshold,
+		"uniform_row_height", et->uniform_row_height,
+		"selection_model", et->selection,
+		NULL);
 
 	g_signal_connect (G_OBJECT (et->group), "cursor_change",
 			  G_CALLBACK (group_cursor_change), et);
@@ -971,20 +1025,25 @@ et_build_groups (ETable *et)
 		et_disconnect_model (et);
 
 	if (et->is_grouped && (!was_grouped)) {
-		et->table_model_change_id = g_signal_connect (G_OBJECT (et->model), "model_changed",
-							      G_CALLBACK (et_table_model_changed), et);
+		et->table_model_change_id = g_signal_connect (
+			et->model, "model_changed",
+			G_CALLBACK (et_table_model_changed), et);
 
-		et->table_row_change_id = g_signal_connect (G_OBJECT (et->model), "model_row_changed",
-							    G_CALLBACK (et_table_row_changed), et);
+		et->table_row_change_id = g_signal_connect (
+			et->model, "model_row_changed",
+			G_CALLBACK (et_table_row_changed), et);
 
-		et->table_cell_change_id = g_signal_connect (G_OBJECT (et->model), "model_cell_changed",
-							     G_CALLBACK (et_table_cell_changed), et);
+		et->table_cell_change_id = g_signal_connect (
+			et->model, "model_cell_changed",
+			G_CALLBACK (et_table_cell_changed), et);
 
-		et->table_rows_inserted_id = g_signal_connect (G_OBJECT (et->model), "model_rows_inserted",
-							       G_CALLBACK (et_table_rows_inserted), et);
+		et->table_rows_inserted_id = g_signal_connect (
+			et->model, "model_rows_inserted",
+			G_CALLBACK (et_table_rows_inserted), et);
 
-		et->table_rows_deleted_id = g_signal_connect (G_OBJECT (et->model), "model_rows_deleted",
-							      G_CALLBACK (et_table_rows_deleted), et);
+		et->table_rows_deleted_id = g_signal_connect (
+			et->model, "model_rows_deleted",
+			G_CALLBACK (et_table_rows_deleted), et);
 
 	}
 
@@ -1029,9 +1088,15 @@ changed_idle (gpointer data)
 static void
 et_canvas_realize (GtkWidget *canvas, ETable *e_table)
 {
+	GtkWidget *widget;
+	GtkStyle *style;
+
+	widget = GTK_WIDGET (e_table->table_canvas);
+	style = gtk_widget_get_style (widget);
+
 	gnome_canvas_item_set(
 		e_table->white_item,
-		"fill_color_gdk", &GTK_WIDGET(e_table->table_canvas)->style->base[GTK_STATE_NORMAL],
+		"fill_color_gdk", &style->base[GTK_STATE_NORMAL],
 		NULL);
 
 	CHECK_HORIZONTAL(e_table);
@@ -1052,11 +1117,7 @@ et_eti_leave_edit (ETable *et)
 {
 	GnomeCanvas *canvas = et->table_canvas;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (gtk_widget_has_focus (GTK_WIDGET (canvas))) {
-#else
-	if (GTK_WIDGET_HAS_FOCUS(canvas)) {
-#endif
 		GnomeCanvasItem *item = GNOME_CANVAS(canvas)->focused_item;
 
 		if (E_IS_TABLE_ITEM(item)) {
@@ -1208,6 +1269,9 @@ static void
 e_table_setup_table (ETable *e_table, ETableHeader *full_header, ETableHeader *header,
 		     ETableModel *model)
 {
+	GtkWidget *widget;
+	GtkStyle *style;
+
 	e_table->table_canvas = GNOME_CANVAS (e_canvas_new ());
 	g_signal_connect (
 		G_OBJECT (e_table->table_canvas), "size_allocate",
@@ -1247,12 +1311,15 @@ e_table_setup_table (ETable *e_table, ETableHeader *full_header, ETableHeader *h
 	g_signal_connect (G_OBJECT(e_table->table_canvas), "reflow",
 			  G_CALLBACK (table_canvas_reflow), e_table);
 
-	gtk_widget_show (GTK_WIDGET (e_table->table_canvas));
+	widget = GTK_WIDGET (e_table->table_canvas);
+	style = gtk_widget_get_style (widget);
+
+	gtk_widget_show (widget);
 
 	e_table->white_item = gnome_canvas_item_new(
 		gnome_canvas_root(e_table->table_canvas),
 		e_canvas_background_get_type(),
-		"fill_color_gdk", &GTK_WIDGET(e_table->table_canvas)->style->base[GTK_STATE_NORMAL],
+		"fill_color_gdk", &style->base[GTK_STATE_NORMAL],
 		NULL);
 
 	g_signal_connect (G_OBJECT (e_table->white_item), "event",
@@ -1321,12 +1388,19 @@ e_table_fill_table (ETable *e_table, ETableModel *model)
 void
 e_table_set_state_object(ETable *e_table, ETableState *state)
 {
-	GValue *val = g_new0 (GValue, 1);
+	GValue *val;
+	GtkWidget *widget;
+	GtkAllocation allocation;
+
+	val = g_new0 (GValue, 1);
 	g_value_init (val, G_TYPE_DOUBLE);
 
 	connect_header (e_table, state);
 
-	g_value_set_double (val, (gdouble) (GTK_WIDGET(e_table->table_canvas)->allocation.width));
+	widget = GTK_WIDGET (e_table->table_canvas);
+	gtk_widget_get_allocation (widget, &allocation);
+
+	g_value_set_double (val, (gdouble) allocation.width);
 	g_object_set_property (G_OBJECT (e_table->header), "width", val);
 	g_free (val);
 
@@ -1528,7 +1602,11 @@ et_real_construct (ETable *e_table, ETableModel *etm, ETableExtras *ete,
 {
 	gint row = 0;
 	gint col_count, i;
-	GValue *val = g_new0 (GValue, 1);
+	GValue *val;
+	GtkLayout *layout;
+	GtkAdjustment *adjustment;
+
+	val = g_new0 (GValue, 1);
 	g_value_init (val, G_TYPE_OBJECT);
 
 	if (ete)
@@ -1541,7 +1619,9 @@ et_real_construct (ETable *e_table, ETableModel *etm, ETableExtras *ete,
 
 	e_table->use_click_to_add = specification->click_to_add;
 	e_table->use_click_to_add_end = specification->click_to_add_end;
-	e_table->click_to_add_message = specification->click_to_add_message ? g_strdup (dgettext (e_table->domain, specification->click_to_add_message)) : NULL;
+	e_table->click_to_add_message = specification->click_to_add_message ?
+		g_strdup (dgettext (e_table->domain,
+		specification->click_to_add_message)) : NULL;
 	e_table->alternating_row_colors = specification->alternating_row_colors;
 	e_table->horizontal_draw_grid = specification->horizontal_draw_grid;
 	e_table->vertical_draw_grid = specification->vertical_draw_grid;
@@ -1607,20 +1687,21 @@ et_real_construct (ETable *e_table, ETableModel *etm, ETableExtras *ete,
 	e_table_setup_table (e_table, e_table->full_header, e_table->header, etm);
 	e_table_fill_table (e_table, etm);
 
-	gtk_layout_get_vadjustment (GTK_LAYOUT (e_table->table_canvas))->step_increment = 20;
-	gtk_adjustment_changed(gtk_layout_get_vadjustment (GTK_LAYOUT (e_table->table_canvas)));
-	gtk_layout_get_hadjustment (GTK_LAYOUT (e_table->table_canvas))->step_increment = 20;
-	gtk_adjustment_changed(gtk_layout_get_hadjustment (GTK_LAYOUT (e_table->table_canvas)));
+	layout = GTK_LAYOUT (e_table->table_canvas);
+
+	adjustment = gtk_layout_get_vadjustment (layout);
+	gtk_adjustment_set_step_increment (adjustment, 20);
+
+	adjustment = gtk_layout_get_hadjustment (layout);
+	gtk_adjustment_set_step_increment (adjustment, 20);
 
 	if (!specification->no_headers) {
-		/*
-		 * The header
-		 */
+		/* The header */
 		gtk_table_attach (GTK_TABLE (e_table), GTK_WIDGET (e_table->header_canvas),
 				  0, 1, 0 + row, 1 + row,
 				  GTK_FILL | GTK_EXPAND,
 				  GTK_FILL, 0, 0);
-		row ++;
+		row++;
 	}
 	gtk_table_attach (GTK_TABLE (e_table), GTK_WIDGET (e_table->table_canvas),
 			  0, 1, 0 + row, 1 + row,
@@ -1776,7 +1857,10 @@ e_table_construct_from_spec_file (ETable *e_table, ETableModel *etm, ETableExtra
  * The newly created #ETable or %NULL if there's an error.
  **/
 GtkWidget *
-e_table_new (ETableModel *etm, ETableExtras *ete, const gchar *spec, const gchar *state)
+e_table_new (ETableModel *etm,
+             ETableExtras *ete,
+             const gchar *spec,
+             const gchar *state)
 {
 	ETable *e_table;
 
@@ -1813,7 +1897,10 @@ e_table_new (ETableModel *etm, ETableExtras *ete, const gchar *spec, const gchar
  * The newly created #ETable or %NULL if there's an error.
  **/
 GtkWidget *
-e_table_new_from_spec_file (ETableModel *etm, ETableExtras *ete, const gchar *spec_fn, const gchar *state_fn)
+e_table_new_from_spec_file (ETableModel *etm,
+                            ETableExtras *ete,
+                            const gchar *spec_fn,
+                            const gchar *state_fn)
 {
 	ETable *e_table;
 
@@ -2237,25 +2324,22 @@ set_scroll_adjustments   (ETable *table,
 			  GtkAdjustment *hadjustment,
 			  GtkAdjustment *vadjustment)
 {
-	if (vadjustment != NULL) {
-		vadjustment->step_increment = 20;
-		gtk_adjustment_changed(vadjustment);
-	}
-	if (hadjustment != NULL) {
-		hadjustment->step_increment = 20;
-		gtk_adjustment_changed(hadjustment);
-	}
+	if (vadjustment != NULL)
+		gtk_adjustment_set_step_increment (vadjustment, 20);
+
+	if (hadjustment != NULL)
+		gtk_adjustment_set_step_increment (hadjustment, 20);
 
 	if (table->table_canvas != NULL) {
-		gtk_layout_set_hadjustment (GTK_LAYOUT(table->table_canvas),
-					    hadjustment);
-		gtk_layout_set_vadjustment (GTK_LAYOUT(table->table_canvas),
-					    vadjustment);
+		gtk_layout_set_hadjustment (
+			GTK_LAYOUT(table->table_canvas), hadjustment);
+		gtk_layout_set_vadjustment (
+			GTK_LAYOUT(table->table_canvas), vadjustment);
 	}
 
 	if (table->header_canvas != NULL)
-		gtk_layout_set_hadjustment (GTK_LAYOUT(table->header_canvas),
-					    hadjustment);
+		gtk_layout_set_hadjustment (
+			GTK_LAYOUT(table->header_canvas), hadjustment);
 }
 
 /**
@@ -2384,7 +2468,9 @@ e_table_get_cell_at (ETable *table,
 		     gint x, gint y,
 		     gint *row_return, gint *col_return)
 {
-	g_return_if_fail (table != NULL);
+	GtkAdjustment *adjustment;
+	GtkLayout *layout;
+
 	g_return_if_fail (E_IS_TABLE (table));
 	g_return_if_fail (row_return != NULL);
 	g_return_if_fail (col_return != NULL);
@@ -2392,9 +2478,16 @@ e_table_get_cell_at (ETable *table,
 	/* FIXME it would be nice if it could handle a NULL row_return or
 	 * col_return gracefully.  */
 
-	x += GTK_LAYOUT(table->table_canvas)->hadjustment->value;
-	y += GTK_LAYOUT(table->table_canvas)->vadjustment->value;
-	e_table_group_compute_location(table->group, &x, &y, row_return, col_return);
+	layout = GTK_LAYOUT (table->table_canvas);
+
+	adjustment = gtk_layout_get_hadjustment (layout);
+	x += gtk_adjustment_get_value (adjustment);
+
+	adjustment = gtk_layout_get_vadjustment (layout);
+	y += gtk_adjustment_get_value (adjustment);
+
+	e_table_group_compute_location (
+		table->group, &x, &y, row_return, col_return);
 }
 
 /**
@@ -2402,8 +2495,10 @@ e_table_get_cell_at (ETable *table,
  * @table: The #ETable.
  * @row: The row to get the geometry of.
  * @col: The col to get the geometry of.
- * @x_return: Returns the x coordinate of the upper left hand corner of the cell with respect to the widget.
- * @y_return: Returns the y coordinate of the upper left hand corner of the cell with respect to the widget.
+ * @x_return: Returns the x coordinate of the upper left hand corner
+ *            of the cell with respect to the widget.
+ * @y_return: Returns the y coordinate of the upper left hand corner
+ *            of the cell with respect to the widget.
  * @width_return: Returns the width of the cell.
  * @height_return: Returns the height of the cell.
  *
@@ -2416,24 +2511,43 @@ e_table_get_cell_geometry (ETable *table,
 			   gint *x_return, gint *y_return,
 			   gint *width_return, gint *height_return)
 {
-	g_return_if_fail (table != NULL);
+	GtkAdjustment *adjustment;
+	GtkAllocation allocation;
+	GtkLayout *layout;
+
 	g_return_if_fail (E_IS_TABLE (table));
 
-	e_table_group_get_cell_geometry(table->group, &row, &col, x_return, y_return, width_return, height_return);
+	layout = GTK_LAYOUT (table->table_canvas);
+
+	e_table_group_get_cell_geometry (
+		table->group, &row, &col, x_return, y_return,
+		width_return, height_return);
+
+	if (x_return && table->table_canvas) {
+		adjustment = gtk_layout_get_hadjustment (layout);
+		(*x_return) -= gtk_adjustment_get_value (adjustment);
+	}
 
-	if (x_return && table->table_canvas)
-		(*x_return) -= GTK_LAYOUT(table->table_canvas)->hadjustment->value;
 	if (y_return) {
-		if (table->table_canvas)
-			(*y_return) -= GTK_LAYOUT(table->table_canvas)->vadjustment->value;
-		if (table->header_canvas)
-			(*y_return) += GTK_WIDGET(table->header_canvas)->allocation.height;
+		if (table->table_canvas) {
+			adjustment = gtk_layout_get_vadjustment (layout);
+			(*y_return) -= gtk_adjustment_get_value (adjustment);
+		}
+
+		if (table->header_canvas) {
+			gtk_widget_get_allocation (
+				GTK_WIDGET (table->header_canvas),
+				&allocation);
+			(*y_return) += allocation.height;
+		}
 	}
 }
 
 /**
  * e_table_get_mouse_over_cell:
- * Similar to e_table_get_cell_at, only here we check based on the mouse motion information in the group.
+ *
+ * Similar to e_table_get_cell_at, only here we check
+ * based on the mouse motion information in the group.
  **/
 void
 e_table_get_mouse_over_cell (ETable *table, gint *row, gint *col)
@@ -2578,30 +2692,39 @@ e_table_drag_highlight (ETable *table,
 			gint     row,
 			gint     col)
 {
-	g_return_if_fail(table != NULL);
-	g_return_if_fail(E_IS_TABLE(table));
+	GtkAdjustment *adjustment;
+	GtkAllocation allocation;
+	GtkLayout *layout;
+	GtkStyle *style;
+
+	g_return_if_fail (E_IS_TABLE (table));
+
+	layout = GTK_LAYOUT (table->table_canvas);
+	style = gtk_widget_get_style (GTK_WIDGET (table));
+	gtk_widget_get_allocation (GTK_WIDGET (layout), &allocation);
 
 	if (row != -1) {
 		gint x, y, width, height;
 		if (col == -1) {
 			e_table_get_cell_geometry (table, row, 0, &x, &y, &width, &height);
 			x = 0;
-			width = GTK_WIDGET (table->table_canvas)->allocation.width;
+			width = allocation.width;
 		} else {
 			e_table_get_cell_geometry (table, row, col, &x, &y, &width, &height);
-			x += GTK_LAYOUT(table->table_canvas)->hadjustment->value;
+			adjustment = gtk_layout_get_hadjustment (layout);
+			x += gtk_adjustment_get_value (adjustment);
 		}
-		y += GTK_LAYOUT(table->table_canvas)->vadjustment->value;
+
+		adjustment = gtk_layout_get_vadjustment (layout);
+		y += gtk_adjustment_get_value (adjustment);
 
 		if (table->drop_highlight == NULL) {
-			table->drop_highlight =
-				gnome_canvas_item_new (gnome_canvas_root (table->table_canvas),
-						       gnome_canvas_rect_get_type (),
-						       "fill_color", NULL,
-						       /*						       "outline_color", "black",
-						       "width_pixels", 1,*/
-						       "outline_color_gdk", &(GTK_WIDGET (table)->style->fg[GTK_STATE_NORMAL]),
-						       NULL);
+			table->drop_highlight = gnome_canvas_item_new (
+				gnome_canvas_root (table->table_canvas),
+				gnome_canvas_rect_get_type (),
+				"fill_color", NULL,
+				"outline_color_gdk", &style->fg[GTK_STATE_NORMAL],
+				NULL);
 		}
 		gnome_canvas_item_set (table->drop_highlight,
 				       "x1", (gdouble) x,
@@ -2901,8 +3024,15 @@ scroll_timeout (gpointer data)
 {
 	ETable *et = data;
 	gint dx = 0, dy = 0;
-	GtkAdjustment *h, *v;
-	gdouble hvalue, vvalue;
+	GtkAdjustment *adjustment;
+	GtkLayout *layout;
+	gdouble old_h_value;
+	gdouble new_h_value;
+	gdouble old_v_value;
+	gdouble new_v_value;
+	gdouble page_size;
+	gdouble lower;
+	gdouble upper;
 
 	if (et->scroll_direction & ET_SCROLL_DOWN)
 		dy += 20;
@@ -2914,22 +3044,37 @@ scroll_timeout (gpointer data)
 	if (et->scroll_direction & ET_SCROLL_LEFT)
 		dx -= 20;
 
-	h = GTK_LAYOUT(et->table_canvas)->hadjustment;
-	v = GTK_LAYOUT(et->table_canvas)->vadjustment;
+	layout = GTK_LAYOUT (et->table_canvas);
 
-	hvalue = h->value;
-	vvalue = v->value;
+	adjustment = gtk_layout_get_hadjustment (layout);
 
-	gtk_adjustment_set_value(h, CLAMP(h->value + dx, h->lower, h->upper - h->page_size));
-	gtk_adjustment_set_value(v, CLAMP(v->value + dy, v->lower, v->upper - v->page_size));
+	lower = gtk_adjustment_get_lower (adjustment);
+	upper = gtk_adjustment_get_upper (adjustment);
+	page_size = gtk_adjustment_get_page_size (adjustment);
 
-	if (h->value != hvalue ||
-	    v->value != vvalue)
-		do_drag_motion(et,
-			       et->last_drop_context,
-			       et->last_drop_x,
-			       et->last_drop_y,
-			       et->last_drop_time);
+	old_h_value = gtk_adjustment_get_value (adjustment);
+	new_h_value = CLAMP (old_h_value + dx, lower, upper - page_size);
+
+	gtk_adjustment_set_value (adjustment, new_h_value);
+
+	adjustment = gtk_layout_get_vadjustment (layout);
+
+	lower = gtk_adjustment_get_lower (adjustment);
+	upper = gtk_adjustment_get_upper (adjustment);
+	page_size = gtk_adjustment_get_page_size (adjustment);
+
+	old_v_value = gtk_adjustment_get_value (adjustment);
+	new_v_value = CLAMP (old_v_value + dy, lower, upper - page_size);
+
+	gtk_adjustment_set_value (adjustment, new_v_value);
+
+	if (new_h_value != old_h_value || new_v_value != old_v_value)
+		do_drag_motion (
+			et,
+			et->last_drop_context,
+			et->last_drop_x,
+			et->last_drop_y,
+			et->last_drop_time);
 
 	return TRUE;
 }
@@ -3001,28 +3146,27 @@ et_drag_motion(GtkWidget *widget,
 	       guint time,
 	       ETable *et)
 {
+	GtkAllocation allocation;
 	gboolean ret_val;
 	guint direction = 0;
 
+	gtk_widget_get_allocation (widget, &allocation);
+
 	et->last_drop_x = x;
 	et->last_drop_y = y;
 	et->last_drop_time = time;
 	et->last_drop_context = context;
 	context_connect (et, context);
 
-	ret_val = do_drag_motion (et,
-				  context,
-				  x,
-				  y,
-				  time);
+	ret_val = do_drag_motion (et, context, x, y, time);
 
 	if (y < 20)
 		direction |= ET_SCROLL_UP;
-	if (y > widget->allocation.height - 20)
+	if (y > allocation.height - 20)
 		direction |= ET_SCROLL_DOWN;
 	if (x < 20)
 		direction |= ET_SCROLL_LEFT;
-	if (x > widget->allocation.width - 20)
+	if (x > allocation.width - 20)
 		direction |= ET_SCROLL_RIGHT;
 
 	if (direction != 0)
@@ -3336,47 +3480,48 @@ e_table_class_init (ETableClass *class)
 
 	g_object_class_install_property (object_class, PROP_LENGTH_THRESHOLD,
 					 g_param_spec_int ("length_threshold",
-							   _("Length Threshold"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Length Threshold",
+							   NULL,
 							   0, G_MAXINT, 0,
 							   G_PARAM_WRITABLE));
 
 	g_object_class_install_property (object_class, PROP_UNIFORM_ROW_HEIGHT,
 					 g_param_spec_boolean ("uniform_row_height",
-							       _("Uniform row height"),
-							       /*_( */"XXX blurb" /*)*/,
+							       "Uniform row height",
+							       NULL,
 							       FALSE,
 							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_ALWAYS_SEARCH,
 					 g_param_spec_boolean ("always_search",
-							       _("Always search"),
-							       /*_( */"XXX blurb" /*)*/,
+							       "Always search",
+							       NULL,
 							       FALSE,
 							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_USE_CLICK_TO_ADD,
 					 g_param_spec_boolean ("use_click_to_add",
-							       _("Use click to add"),
-							       /*_( */"XXX blurb" /*)*/,
+							       "Use click to add",
+							       NULL,
 							       FALSE,
 							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_MODEL,
 					 g_param_spec_object ("model",
-							      _("Model"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Model",
+							      NULL,
 							      E_TABLE_MODEL_TYPE,
 							      G_PARAM_READABLE));
 
 	gtk_widget_class_install_style_property (widget_class,
 					 g_param_spec_int ("vertical-spacing",
-							   _("Vertical Row Spacing"),
-							   _("Vertical space between rows. It is added to top and to bottom of a row"),
+							   "Vertical Row Spacing",
+							   "Vertical space between rows. It is added to top and to bottom of a row",
 							   0,
 							   G_MAXINT,
 							   3,
-							   G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+							   G_PARAM_READABLE |
+							   G_PARAM_STATIC_STRINGS));
 
 	gal_a11y_e_table_init ();
 }
