@@ -202,7 +202,6 @@ etsm_node_deleted (ETreeModel *etm, ETreePath child, ETreeSelectionModel *etsm)
 	restore_cursor (etsm, etm);
 }
 
-
 static void
 add_model(ETreeSelectionModel *etsm, ETreeModel *model)
 {
@@ -302,7 +301,7 @@ etsm_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *ps
 {
 	ETreeSelectionModel *etsm = E_TREE_SELECTION_MODEL (object);
 
-	switch (prop_id){
+	switch (prop_id) {
 	case PROP_CURSOR_ROW:
 		g_value_set_int (value, get_cursor_row(etsm));
 		break;
@@ -327,7 +326,7 @@ etsm_set_property (GObject *object, guint prop_id, const GValue *value, GParamSp
 	ESelectionModel *esm = E_SELECTION_MODEL (object);
 	ETreeSelectionModel *etsm = E_TREE_SELECTION_MODEL (object);
 
-	switch (prop_id){
+	switch (prop_id) {
 	case PROP_CURSOR_ROW:
 		e_selection_model_do_something(esm, g_value_get_int (value), etsm->priv->cursor_col, 0);
 		break;
@@ -380,7 +379,6 @@ etsm_is_row_selected (ESelectionModel *selection,
 	return etsm_is_path_selected (etsm, path);
 }
 
-
 typedef struct {
 	ETreeSelectionModel *etsm;
 	EForeachFunc callback;
@@ -741,7 +739,6 @@ e_tree_selection_model_get_cursor (ETreeSelectionModel *etsm)
 	return etsm->priv->cursor_path;
 }
 
-
 static void
 e_tree_selection_model_init (ETreeSelectionModel *etsm)
 {
@@ -803,29 +800,29 @@ e_tree_selection_model_class_init (ETreeSelectionModelClass *klass)
 
 	g_object_class_install_property (object_class, PROP_CURSOR_ROW,
 					 g_param_spec_int ("cursor_row",
-							   _("Cursor Row"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Cursor Row",
+							   NULL,
 							   0, G_MAXINT, 0,
 							   G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_CURSOR_COL,
 					 g_param_spec_int ("cursor_col",
-							   _("Cursor Column"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Cursor Column",
+							   NULL,
 							   0, G_MAXINT, 0,
 							   G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_MODEL,
 					 g_param_spec_object ("model",
-							      _("Model"),
-							      "XXX blurb",
+							      "Model",
+							      NULL,
 							      E_TREE_MODEL_TYPE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_ETTA,
 					 g_param_spec_object ("etta",
 							      "ETTA",
-							      "XXX blurb",
+							      NULL,
 							      E_TREE_TABLE_ADAPTER_TYPE,
 							      G_PARAM_READWRITE));
 
